(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     81675,       2806]*)
(*NotebookOutlinePosition[    123951,       4314]*)
(*  CellTagsIndexPosition[    123648,       4301]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[ValueBox["FileName"]], "Title",
  CounterAssignments->{{"Title", 20}, {"SubTitle", 0}, {"SubSubTitle", 0}, {
      "Section", 0}, {"SubSection", 0}, {"SubSubSection", 0}, {
      "NumberedEquation", 0}, {"NumberedFigure", 0}, {"NumberedTable", 0}}],

Cell["\<\
Fragesteller:\t16.  7.2002\tNorbert S\[UDoubleDot]dland
Bearbeitung:\t16.  7.2002 - 16.  4.2003\tNorbert S\[UDoubleDot]dland
Letzte Berechnung:\t16.  4.2003\tNorbert S\[UDoubleDot]dland\
\>", "Subsubtitle",
  TextAlignment->Left],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ". Frage"
}], "Section"],

Cell[TextData[{
  "Das Wesen der ",
  Cell[BoxData[
      \(TraditionalForm\`ArcTan[\ ]\)]],
  "-Funktion soll n\[ADoubleDot]her verstanden werden."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ". Antwort"
}], "Section"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Vorbereitung"
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Regel ",
  Cell[BoxData[
      \(TraditionalForm\`TimesRule\)]]
}], "Subsubsection"],

Cell[TextData[{
  "Das Produkt zweier Potenzen kann bei gleicher Potenzzahl eventuell \
vereinfacht werden. Da eine Ver\[ADoubleDot]nderung der Funktion ",
  Cell[BoxData[
      \(TraditionalForm\`Times[\ ]\)]],
  " in aller Regel ungeahnte Seiteneffekte bewirkt, wird eine \
Transformationsregel ",
  Cell[BoxData[
      \(TraditionalForm\`TimesRule\)]],
  " geschaffen, die die Vereinfachung nur bei explizitem Wunsch bewirkt:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Protect[TimesRule]; \n
    \(Function[\n\tClear[TimesRule]\ ; \n\t\n\t
        TimesRule::usage = \n\t\t
          "\<TimesRule is a Rule adding some properties to Times where \
needed.\>"\ ; \n\t\n\t
        TimesRule
           = {\n\t\t
             (********************************************************) \n
            \t\t\tTimes[Power[term1_, pow_], Power[term2_, pow_], term3_.] /; 
                \n\t\t\t\t
                Simplify[term1\ term2]\ \  =!= \ \ \((term1\ term2)\) :> \n
              \t\t (********************************************************) 
                \n\t\tterm3\ PowerExpand[Simplify[term1\ term2]^pow]\ , \n\t\t
            \n\t\t (********************************************************) 
              \n\t\t\tTimes[Power[term1_, pow_], Power[term2_, pow_], term3_.]
                   /; \n\t\t\t\t
                ExpandAll[term1\ term2]\ \ \  =!= \ \ \ \((term1\ term2)\) :> 
              \n\t\t (********************************************************\
) \n\t\tterm3\ PowerExpand[ExpandAll[term1\ term2]^pow]\n\t}\ ; \n\t\n\t
        Protect[#]\n]\)[Unprotect[TimesRule]]\)], "Input"],

Cell[BoxData[
    \({"TimesRule"}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Diese Eigenschaft ist bei ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 3.00 noch nicht implementiert und f\[UDoubleDot]hrt deshalb zum Beispiel \
bei der Proberechnung zu den kubischen Gleichungen auf \
\[CapitalUDoubleDot]berraschungen."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Funktion ",
  Cell[BoxData[
      \(TraditionalForm\`LogSimplify[\ ]\)]]
}], "Subsubsection"],

Cell["\<\
Zur Vereinfachung logarithmischer Terme ist eine eigene Routine notwendig:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Protect[LogSimplify]; \n
    \(Function[\n\tClear[LogSimplify]; \n\t\n\t
        LogSimplify::usage = \n\t\t
          "\<LogSimplify[expr] applies `LogSimplifyRules` to `expr`.\>"; \n\n
        \t (*********************) \n\t\t
        LogSimplify[expr_] := \n\t (*********************) \n\t
          expr //. LogSimplifyRules; \n\t\n\tProtect[#]\n]\)[
      Unprotect[LogSimplify]]\)], "Input"],

Cell[BoxData[
    \({"LogSimplify"}\)], "Output"]
}, Open  ]],

Cell["Diese Routine greift auf folgende Ersetzungsregel zur\[UDoubleDot]ck:", 
  "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Protect[LogSimplifyRules]; \n
    \(Function[\n\tClear[LogSimplifyRules]; \n\t\n\t
        LogSimplifyRules::usage = \n\t\t
          "\<LogSimplifyRules is a connection of Rules\>"\ <>\n\t\t\t\ 
            "\< simplfying expressions containing logarithmic terms.\>"; \n\t
        \n\t (********************) \n\t\t
        LogSimplifyRules\  = \n\t (********************) \n
          \t{\t\t\n\t\t (*************************) \n\t\t\t
            c_.\ Log[a_] + c_.  Log[b_] :> \n\t\t
               (*************************) \n\t\tc\ Log[a\ b]\ , \n\t\n\t\t
             (*************) \n\t\t\t
            a_\ Log[b_] :> \n\t\t (*************) \n\t\t
              Log[b\^a]\  /; \ FreeQ[{a}, Complex]\ , \n\n\t\t
             (*******************) \n\t\t\t
            a_Times\ Log[b_] :> \n\t\t (*******************) \n\t\t
              Times@@Cases[a, _Complex] 
                Log[b\^\(a\/Times@@Cases[a, _Complex]\)]\n\t}\ ; \n\t\t\t\n\t
        Protect[#]\n]\)[Unprotect[LogSimplifyRules]]\)], "Input"],

Cell[BoxData[
    \({"LogSimplifyRules"}\)], "Output"]
}, Open  ]],

Cell["\<\
Die Arbeitsweise der Funktion ist die, da\[SZ] komplexe Terme vor den \
Logarithmen stehen gelassen werden, w\[ADoubleDot]hrend sie ansonsten korrekt \
zum Einsatz kommen:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(a\ Log[x + \[ImaginaryI], y - \[ImaginaryI]] + b\ Log[z] // LogSimplify
      \)], "Input"],

Cell[BoxData[
    \(Log[\((\(-I\) + y)\)\^a]\/Log[I + x] + Log[z\^b]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(a\ \[ImaginaryI]\ Log[x, y - \[ImaginaryI]] + 
        b\ \[ImaginaryI]\ Log[z] // LogSimplify\)], "Input"],

Cell[BoxData[
    \(I\ Log[\((\(-I\) + y)\)\^\(a\/Log[x]\)\ z\^b]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[ImaginaryI]\ a\^2\ Log[a, b] // LogSimplify\)], "Input"],

Cell[BoxData[
    \(I\ Log[b\^\(a\^2\/Log[a]\)]\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Analytische Formulierung"
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Motivation"
}], "Subsubsection"],

Cell[TextData[{
  "F\[UDoubleDot]r die ",
  Cell[BoxData[
      \(TraditionalForm\`ArcTan[\ ]\)]],
  "-Funktion findet sich nicht immer in der Literatur eine analytische \
Formulierung, f\[UDoubleDot]r ",
  Cell[BoxData[
      \(TraditionalForm\`Tan[\ ]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`Sin[\ ]\)]],
  " und ",
  Cell[BoxData[
      \(TraditionalForm\`Cos[\ ]\)]],
  " dagegen ist eine derartige Ersatzschreibweise \[UDoubleDot]blich, ebenso \
f\[UDoubleDot]r die verwandeten Funktionen ",
  Cell[BoxData[
      \(TraditionalForm\`Sinh[\ ]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`Cosh[\ ]\)]],
  " etc. und sogar deren Area-Funktionen:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(demo[1] = {\(Exp[\[ImaginaryI]\ x] + Exp[\(-\[ImaginaryI]\)\ x]\)\/2, 
        \(Exp[\[ImaginaryI]\ x] - Exp[\(-\[ImaginaryI]\)\ x]\)\/\(2  
            \[ImaginaryI]\)}; \ndemo[1] // FullSimplify\)], "Input"],

Cell[BoxData[
    \({Cos[x], Sin[x]}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Zum tieferen Verst\[ADoubleDot]ndnis der ",
  Cell[BoxData[
      \(TraditionalForm\`ArcTan[\ ]\)]],
  "-Funktion ist ebenfalls eine explizite Darstellung durch einfachere \
Funktionen sinnvoll, wobei diese Darstellung auch komplexe Terme enthalten \
darf. Sie gilt ohnehin f\[UDoubleDot]r komplexwertige Argumente."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Herleitung \[UDoubleDot]ber trigonometrische Funktionen"
}], "Subsubsection"],

Cell[TextData[{
  "Wird der Term ",
  Cell[BoxData[
      \(TraditionalForm\`Exp[\[ImaginaryI]\ x] \[Rule] a\)]],
  " als eigenst\[ADoubleDot]ndige Variable aufgefa\[SZ]t, so ergibt sich eine \
Bestimmungsgleichung f\[UDoubleDot]r die Funktion ",
  Cell[BoxData[
      \(TraditionalForm\`ArcTan[\ ]\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(bestimmung[1] = Last[demo[1]]\/First[demo[1]] == Tan[x]\), 
    \(bestimmung[1] // FullSimplify\)}], "Input"],

Cell[BoxData[
    \(\(-\(\(I\ \((\(-E\^\(\(-I\)\ x\)\) + E\^\(I\ x\))
              \)\)\/\(E\^\(\(-I\)\ x\) + E\^\(I\ x\)\)\)\) == Tan[x]\)], 
  "Output"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Diese Bestimmungsgleichung wird mit ",
  Cell[BoxData[
      \(TraditionalForm\`y = Tan[x]\)]],
  " ersetzt und jeweils nach ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " aufgel\[ODoubleDot]st:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(erg[1] = \(Solve[# == y, x]&\)/@\(List@@bestimmung[1]\)\)], "Input"],

Cell[BoxData[
    \(Solve::"ifun" \( : \ \) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message"],

Cell[BoxData[
    \(Solve::"ifun" \( : \ \) 
      "Inverse functions are being used by \!\(Solve\), so some solutions may \
not be found."\)], "Message"],

Cell[BoxData[
    \({{{x \[Rule] \(-I\)\ Log[\(-\@\(\(I - y\)\/\(I + y\)\)\)]}, {
          x \[Rule] \(-I\)\ Log[\@\(\(I - y\)\/\(I + y\)\)]}}, {{
          x \[Rule] ArcTan[y]}}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Damit existiert eine analytische Formulierung f\[UDoubleDot]r die ",
  Cell[BoxData[
      \(TraditionalForm\`ArcTan[\ ]\)]],
  "-Funktion. Da die ",
  Cell[BoxData[
      \(TraditionalForm\`ArcTan[\ ]\)]],
  "-Funktion ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\)]],
  "-periodisch ist, ist eine explizite Kontrolle sinnvoll, welches Ergebnis f\
\[UDoubleDot]r ",
  Cell[BoxData[
      \(TraditionalForm\`y \[Rule] 0\)]],
  " resultiert:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(erg[1] /. y \[Rule] 0\)], "Input"],

Cell[BoxData[
    \({{{x \[Rule] \[Pi]}, {x \[Rule] 0}}, {{x \[Rule] 0}}}\)], "Output"]
}, Open  ]],

Cell["Somit ist die positive Wurzel im Logarithmus zu verwenden:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(erg[1, 1] = Last/@erg[1]\)], "Input"],

Cell[BoxData[
    \({{x \[Rule] \(-I\)\ Log[\@\(\(I - y\)\/\(I + y\)\)]}, {
        x \[Rule] ArcTan[y]}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Das negative Vorzeichen vor der jetzt gefundenen ",
  Cell[BoxData[
      \(TraditionalForm\`ArcTan[\ ]\)]],
  "-Alternative ",
  Cell[BoxData[
      \(TraditionalForm\`erg[1, 1]\)]],
  " verschwindet durch Invertierung des Bruchs oder den Austausch ",
  Cell[BoxData[
      \(TraditionalForm\`\[ImaginaryI] \[Rule] \(-\[ImaginaryI]\)\)]],
  " und anschlie\[SZ]endes K\[UDoubleDot]rzen von ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\)\)]],
  "."
}], "Text"],

Cell["\<\
Die Identit\[ADoubleDot]t der beiden Ausdr\[UDoubleDot]cke ist gezeigt, wenn \
zwei Funktionswerte identisch sind und au\[SZ]erdem die Differentiation \
\[UDoubleDot]bereinstimmt:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(diff[y] = 
      \(\(\[PartialD]\_y\((x /. erg[1])\) // Simplify\) // Flatten\) // Union
        \)], "Input"],

Cell[BoxData[
    \({1\/\(1 + y\^2\)}\)], "Output"]
}, Open  ]],

Cell["Das ist der Fall.", "Text"],

Cell[TextData[{
  "Die ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "-Probe"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(erg[1, 1]\)], "Input"],

Cell[BoxData[
    \({{x \[Rule] \(-I\)\ Log[\@\(\(I - y\)\/\(I + y\)\)]}, {
        x \[Rule] ArcTan[y]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(probe[1] = 
      \(\(\(#1 == #2&\)@@\((x /. erg[1, 1])\) // PowerExpand\) // LogSimplify
          \) // Simplify\)], "Input"],

Cell[BoxData[
    \(\(-\(1\/2\)\)\ I\ Log[\(-\(\(\(-I\) + y\)\/\(I + y\)\)\)] == 
      ArcTan[y]\)], "Output"]
}, Open  ]],

Cell["\<\
versagt, was inhaltlich nichts bedeutet, aber das Erkennen des Zusammenhangs \
wesentlich erschwert.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Herleitung \[UDoubleDot]ber Integral"
}], "Subsubsection"],

Cell["\<\
Eine unabh\[ADoubleDot]ngige Herleitung ergibt sich aus der Integralrechnung \
durch Integration von\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(diff[y]\)], "Input"],

Cell[BoxData[
    \({1\/\(1 + y\^2\)}\)], "Output"]
}, Open  ]],

Cell["\<\
Die Stammfunktion zu diesem Term ergibt sich durch komplexwertige \
Partialbruchzerlegung:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(term[y] = 
      Simplify/@
        \((Apart[First[diff[y]] /. y \[Rule] \[ImaginaryI]\ x] /. 
            x \[Rule] \(-\[ImaginaryI]\)\ y)\)\)], "Input"],

Cell[BoxData[
    \(I\/\(2\ I - 2\ y\) + I\/\(2\ I + 2\ y\)\)], "Output"]
}, Open  ]],

Cell["Eine alternative Darstellung dieses Ergebnisses lautet:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(alternativ[y] = 
      Plus@@Simplify[List@@term[y] /. y \[Rule] \[ImaginaryI]\ x] /. 
        x \[Rule] \(-\[ImaginaryI]\)\ y\)], "Input"],

Cell[BoxData[
    \(1\/\(2 - 2\ I\ y\) + 1\/\(2 + 2\ I\ y\)\)], "Output"]
}, Open  ]],

Cell["Die Partialbruchzerlegung von Hand ergibt:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(vonhand[y] = 
      \(\(1\/2\) 
            \((\[ImaginaryI]\/\(\[ImaginaryI] - y\) + 
                \[ImaginaryI]\/\(\[ImaginaryI] + y\))\) // Expand\) // 
        ExpandAll\)], "Input"],

Cell[BoxData[
    \(I\/\(2\ I - 2\ y\) + I\/\(2\ I + 2\ y\)\)], "Output"]
}, Open  ]],

Cell["\<\
Dieses Ergebnis tauchte auch schon bei der maschinellen Partialbruchzerlegung \
auf:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(term[y] == vonhand[y]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Ein weiterer Versuch pr\[UDoubleDot]ft, ob ",
  Cell[BoxData[
      \(TraditionalForm\`\[ImaginaryI]\^2 \[Equal] \(-1\)\)]],
  " in diesem Zusammenhang auch bei verwechseltem Vorzeichen aufgeht:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(vonhand[y] = 
      Simplify/@
        \((Apart[First[diff[y]] /. y \[Rule] \[ImaginaryI]\ x] /. 
            x \[Rule] \[ImaginaryI]\ y)\)\)], "Input"],

Cell[BoxData[
    \(1\/\(2 + 2\ I\ y\) + I\/\(2\ I + 2\ y\)\)], "Output"]
}, Open  ]],

Cell["Die Partialbruchzerlegungen sind jeweils korrekt:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\({term[y], alternativ[y], vonhand[y]} // Simplify\) // Union\)], 
  "Input"],

Cell[BoxData[
    \({1\/\(1 + y\^2\)}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Die Integration \[UDoubleDot]ber ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]y\)]],
  " ergibt nun ganz eindeutig nat\[UDoubleDot]rliche Logarithmen:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(versuch[1] = \(\[Integral]# \[DifferentialD]y&\)/@\(List@@term[y]\)\)], 
  "Input"],

Cell[BoxData[
    \({ArcTan[y]\/2 - 1\/4\ I\ Log[1 + y\^2], 
      ArcTan[y]\/2 + 1\/4\ I\ Log[1 + y\^2]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(versuch[2] = 
      \(\[Integral]# \[DifferentialD]y&\)/@\(List@@alternativ[y]\)\)], "Input"],

Cell[BoxData[
    \({ArcTan[y]\/2 + 1\/4\ I\ Log[1 + y\^2], 
      ArcTan[y]\/2 - 1\/4\ I\ Log[1 + y\^2]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(versuch[3] = 
      \(\[Integral]# \[DifferentialD]y&\)/@\(List@@vonhand[y]\)\)], "Input"],

Cell[BoxData[
    \({ArcTan[y]\/2 - 1\/4\ I\ Log[1 + y\^2], 
      ArcTan[y]\/2 + 1\/4\ I\ Log[1 + y\^2]}\)], "Output"]
}, Open  ]],

Cell["Die Summe aus beiden Termen ergibt jeweils:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(erg[2] = \(Plus@@versuch[#]&\)/@Range[3] // Union\)], "Input"],

Cell[BoxData[
    \({ArcTan[y]}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Damit ist das Geheimnis der ",
  Cell[BoxData[
      \(TraditionalForm\`ArcTan[\ ]\)]],
  "-Funktion nicht gel\[UDoubleDot]ftet."
}], "Text"],

Cell[TextData[{
  "Um die Formalit\[ADoubleDot]ten der Integration zu erhalten, wird hier ",
  Cell[BoxData[
      \(TraditionalForm\`\[ImaginaryI] \[Rule] z\)]],
  " ersetzt. Dies ist zul\[ADoubleDot]ssig, da das richtige Riemannsche Blatt \
betrachtet wird, wenn die untere Integrationsgrenze Null explizit angegeben \
wird:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(versuch[4] = 
      \(\[Integral]\_0\%y # \[DifferentialD]y&\)/@
        \((term[y] /. Complex[a_, b_] \[Rule] a + c\ b)\)\)], "Input"],

Cell[BoxData[
    \(1\/2\ c\ Log[\(-c\)] - 1\/2\ c\ Log[c] - 1\/2\ c\ Log[\(-c\) + y] + 
      1\/2\ c\ Log[c + y]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(versuch[5] = 
      \(\[Integral]\_0\%y # \[DifferentialD]y&\)/@
        \((alternativ[y] /. Complex[a_, b_] \[Rule] a + c\ b)\)\)], "Input"],

Cell[BoxData[
    \(\(I\ \[Pi]\)\/\(2\ c\) - Log[\(-1\) + c\ y]\/\(2\ c\) + 
      Log[1 + c\ y]\/\(2\ c\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(versuch[6] = 
      \(\[Integral]\_0\%y # \[DifferentialD]y&\)/@
        \((vonhand[y] /. Complex[a_, b_] \[Rule] a + c\ b)\)\)], "Input"],

Cell[BoxData[
    \(\(-\(1\/2\)\)\ c\ Log[c] + 1\/2\ c\ Log[c + y] + 
      Log[1 + c\ y]\/\(2\ c\)\)], "Output"]
}, Open  ]],

Cell["Bei der formalen Integration von Hand ergibt sich dagegen:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(versuch[7] = 
      \(-\(\[ImaginaryI]\/2\)\) Log[\[ImaginaryI] - y] + 
        \(\[ImaginaryI]\/2\) Log[\[ImaginaryI] + y]\)], "Input"],

Cell[BoxData[
    \(\(-\(1\/2\)\)\ I\ Log[I - y] + 1\/2\ I\ Log[I + y]\)], "Output"]
}, Open  ]],

Cell["\<\
Hier ist die untere Integrationsgrenze Null schon automatisch \
ber\[UDoubleDot]cksichtigt:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(versuch[#]&\)/@Range[4, 7] /. y \[Rule] 0 // Union\)], "Input"],

Cell[BoxData[
    \({0}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "-Integrationstechnik"
}], "Subsubsection"],

Cell[TextData[{
  "Dieser Zugang mag hier elegant sein, f\[UDoubleDot]hrt aber auf Trugschl\
\[UDoubleDot]sse, wenn die untere Integrationsgrenze bei der Suche nach \
Stammfunktionen gerade nicht pa\[SZ]t. Das ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "-Programm gew\[ADoubleDot]hrleistet dagegen f\[UDoubleDot]r ",
  Cell[BoxData[
      \(TraditionalForm\`y > 0\)]],
  " korrekte Ergebnisse, speziell im Grenzfall ",
  Cell[BoxData[
      \(TraditionalForm\`c \[Rule] 0\)]],
  ". Derartige Feinheiten werden beim Rechnen von Hand meist doch \
\[UDoubleDot]bersehen."
}], "Text"],

Cell["\<\
Der Grundsatz im Umgang mit der Computeralgebra ist der, da\[SZ] die \
systematischen Wege zur Vermeidung von analytischen Trugschl\[UDoubleDot]ssen \
effizient einstudiert werden. Die Rechenkonsequenz der Maschine ist dabei \
nicht so einfach zu \[UDoubleDot]berlisten wie ein Mensch:\
\>", "Text"],

Cell["\<\
Bei abenteuerlichen Ergebnissen ist nicht immer die Implementierung ung\
\[UDoubleDot]nstig!\
\>", "Text",
  TextAlignment->Center,
  FontSlant->"Italic"],

Cell["\<\
Das Problem mit dem einheitlichen Beginn auf den Riemannschen \
Bl\[ADoubleDot]ttern des komplexwertigen Logarithmus-Ergebnisses einer \
Integration wird nur durch explizit angegebene Integrationsgrenzen wirklich \
gel\[ODoubleDot]st. Langfristig ist dieses Problem der schlecht verstandenen \
Stammfunktionen nur dadurch zu l\[ODoubleDot]sen, da\[SZ] zu jeder \
Stammfunktion auch die zugeh\[ODoubleDot]rigen Integrationsgrenzen angegeben \
werden!\
\>", "Text"],

Cell["\<\
Ein automatisch erzeugtes Stammintegral sollte deshalb das Ergebnis zusammen \
mit einer Warnung ausgeben, die die zugeh\[ODoubleDot]rigen \
Integrationsgrenzen explizit nennt. Diese Warnung sollte vor allem dann \
abgeschaltet werden, wenn die Stammfunktion von einer Funktion aufgerufen \
wird, die konkrete Integrationsgrenzen einsetzen will.\
\>", "Text"],

Cell[TextData[{
  "Au\[SZ]erdem w\[ADoubleDot]re eine M\[ODoubleDot]glichkeit zur Angabe von \
Literaturstellen zum entsprechenden Rechenschritt auf Anfrage \
(\[UDoubleDot]ber eine Option ",
  Cell[BoxData[
      \(TraditionalForm\`ShowLiterature \[Rule] True\)]],
  ") generell nicht verwerflich."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Proberechnung zu den Stammfunktionen"
}], "Subsubsection"],

Cell["Die Differentiation ergibt:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(diff[4] = \(\[PartialD]\_y versuch[4] // Together\) // Simplify\)], 
  "Input"],

Cell[BoxData[
    \(c\^2\/\(c\^2 - y\^2\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(diff[5] = \[PartialD]\_y versuch[5] // Simplify\)], "Input"],

Cell[BoxData[
    \(1\/\(1 - c\^2\ y\^2\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(diff[6] = \[PartialD]\_y versuch[6] // Together\)], "Input"],

Cell[BoxData[
    \(\(2\ c + y + c\^2\ y\)\/\(2\ \((c + y)\)\ \((1 + c\ y)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(diff[7] = \[PartialD]\_y versuch[7] // Simplify\)], "Input"],

Cell[BoxData[
    \(1\/\(1 + y\^2\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "F\[UDoubleDot]r ",
  Cell[BoxData[
      \(TraditionalForm\`c\^2 \[Rule] \(-1\)\)]],
  " ist das jeweils das gesuchte Resultat:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\({diff[4], diff[5], diff[6], diff[7]} /. c \[Rule] \[ImaginaryI] // 
        Simplify\) // Union\)], "Input"],

Cell[BoxData[
    \({1\/\(1 + y\^2\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\({diff[4], diff[5], diff[6], diff[7]} /. 
          c \[Rule] \(-\[ImaginaryI]\) // Simplify\) // Union\)], "Input"],

Cell[BoxData[
    \({1\/\(1 + y\^2\)}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Die R\[UDoubleDot]cksubstitution ",
  Cell[BoxData[
      \(TraditionalForm\`c \[Rule] \[ImaginaryI]\)]],
  " ergibt formal:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(erg[4] = versuch[4] /. c \[Rule] \[ImaginaryI] // ExpandAll\)], "Input"],

Cell[BoxData[
    \(\[Pi]\/2 - 1\/2\ I\ Log[\(-I\) + y] + 1\/2\ I\ Log[I + y]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(erg[5] = versuch[5] /. c \[Rule] \[ImaginaryI] // ExpandAll\)], "Input"],

Cell[BoxData[
    \(\[Pi]\/2 + 1\/2\ I\ Log[\(-1\) + I\ y] - 1\/2\ I\ Log[1 + I\ y]\)], 
  "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(erg[6] = versuch[6] /. c \[Rule] \[ImaginaryI] // ExpandAll\)], "Input"],

Cell[BoxData[
    \(\[Pi]\/4 - 1\/2\ I\ Log[1 + I\ y] + 1\/2\ I\ Log[I + y]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(erg[7] = versuch[7]\)], "Input"],

Cell[BoxData[
    \(\(-\(1\/2\)\)\ I\ Log[I - y] + 1\/2\ I\ Log[I + y]\)], "Output"]
}, Open  ]],

Cell["\<\
Hier sind die Unterschiede beim Betrachten der einzelnen L\[ODoubleDot]sungen \
durchaus vorhanden.\
\>", "Text"],

Cell[TextData[{
  "Die didaktisch optimierte Darstellung des Ergebnisses weicht von der f\
\[UDoubleDot]r Rechenzwecke optimierten ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "-Darstellung auch hier ab und lautet:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(didaktisch
       = {\[ImaginaryI]\ 
          Log[\@\(\(\[ImaginaryI] + y\)\/\(\[ImaginaryI] - y\)\)], 
        \(\[ImaginaryI]\/2\) 
          Log[\(\[ImaginaryI] + y\)\/\(\[ImaginaryI] - y\)], 
        \(\(-\[ImaginaryI]\)\/2\) 
          Log[\(\(-\[ImaginaryI]\) + y\)\/\(\(-\[ImaginaryI]\) - y\)]}\)], 
  "Input"],

Cell[BoxData[
    \({I\ Log[\@\(\(I + y\)\/\(I - y\)\)], 
      1\/2\ I\ Log[\(I + y\)\/\(I - y\)], 
      \(-\(1\/2\)\)\ I\ Log[\(\(-I\) + y\)\/\(\(-I\) - y\)]}\)], "Output"]
}, Open  ]],

Cell["Diese Darstellungen sind korrekt:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\[PartialD]\_y #&\)/@didaktisch // Simplify\) // Union\)], "Input"],

Cell[BoxData[
    \({1\/\(1 + y\^2\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(didaktisch /. y \[Rule] 0 // Union\)], "Input"],

Cell[BoxData[
    \({0}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Die M\[ODoubleDot]glichkeit ",
  Cell[BoxData[
      \(TraditionalForm\`\[ImaginaryI] \[Rule] \(\[PlusMinus]\@\(-1\)\)\)]],
  " ist bei dieser Darstellung noch enthalten! Damit sind die gefundenen \
Funktionen identische Darstellungen der ",
  Cell[BoxData[
      \(TraditionalForm\`ArcTan[\ ]\)]],
  "-Funktion."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Einschub: Erweiterung der Wurzel-Nomenklatur"
}], "Subsubsection"],

Cell[TextData[{
  "Mit ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ist eine Identit\[ADoubleDot]t dieser Art nur schwer zu finden, da die \
Fallunterscheidung beim Wurzelziehen generell unber\[UDoubleDot]cksichtigt \
bleibt und au\[SZ]erdem die Theoreme zur vereinfachenden Zusammenfassung \
logarithmischer Terme nicht implementiert sind."
}], "Text"],

Cell["\<\
Eine korrekte Implementierung der Wurzel beginnt stets bei der reellen \
Wurzel, m\[ODoubleDot]glichst der positiven, und z\[ADoubleDot]hlt dann im \
mathematisch positiven Sinne hoch. Auf diese Weise ist die erstgenannte \
Wurzel eines Terms reell, falls reelle Wurzeln existieren.\
\>", "Text"],

Cell["\<\
Diese Art Wurzelzeichen mu\[SZ] noch implementiert werden. Dazu ist folgender \
Aufbau sinnvoll:\
\>", "Text"],

Cell[BoxData[
    \(Radix[expr_, degree_, counter_] = 
      \(\@expr\%\(degree\  | \ counter\) = 
        expr\^\(1\/\(degree | counter\)\)\)\)], "NumberedEquation"],

Cell[TextData[{
  "Fehlt der Z\[ADoubleDot]hler ",
  Cell[BoxData[
      \(TraditionalForm\`counter\)]],
  ", so ist eine traditionelle Wurzel gemeint, die ja auch bei ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " vorkommt \[Dash] teilweise mit begr\[UDoubleDot]ndeten \
\[CapitalUDoubleDot]berraschungen aufgrund der Genauigkeit. Bei ",
  Cell[BoxData[
      \(TraditionalForm\`degree \[Equal] 0\)]],
  " sind alle verschiedenen Wurzeln gemeinsam gemeint, also der Fall, wo eine \
Fallunterscheidung bez\[UDoubleDot]glich der einzelnen Wurzeln nicht \
erforderlich ist."
}], "Text"],

Cell[TextData[{
  "F\[UDoubleDot]r die ",
  Cell[BoxData[
      \(TraditionalForm\`ArcTan[\ ]\)]],
  "-Funktion gen\[UDoubleDot]gt zum Beispiel die Voraussetzung:"
}], "Text"],

Cell[BoxData[
    \(\[ImaginaryI]\^2 \[Equal] 
      \(-1\ \ \ \ \[DoubleLongLeftRightArrow]\ \ \ \ \[ImaginaryI]\) \[Equal] 
      \@\(-1\)\%\(2 | 0\) \[Equal] \(\[PlusMinus]\@\(-1\)\%\(2 | 1\)\) 
      \[Equal] \(\[MinusPlus]\@\(-1\)\%\(2 | 2\)\) \[Equal] 
      \(\[PlusMinus]\@\(-1\)\%2\) \[Equal] \(\[PlusMinus]\@\(-1\)\)\)], 
  "NumberedEquation"],

Cell[TextData[{
  "Rechenregeln zu den Zeichen ",
  Cell[BoxData[
      \(TraditionalForm\`\[PlusMinus]\)]],
  " oder ",
  Cell[BoxData[
      \(TraditionalForm\`\[MinusPlus]\)]],
  " sind standardm\[ADoubleDot]\[SZ]ig nicht bei ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " vorhanden."
}], "Text"],

Cell[TextData[{
  "Falls die ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "-te Wurzel aus einem komplexen Term zu ziehen ist, beginnt die Z\
\[ADoubleDot]hlung wieder woanders, n\[ADoubleDot]mlich da, wo der komplexe \
Winkel des Arguments auf den ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "-ten Teil (im mathematisch positiven Sinne) reduziert wurde. Diese Art der \
Wurzelziehung ist bei ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " implementiert und korreliert mit der Funktion ",
  Cell[BoxData[
      \(TraditionalForm\`Power[\ ]\)]],
  "."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Probleme bei der Proberechnung"
}], "Subsubsection"],

Cell[TextData[{
  "Der Vergleich mit den schon gefundenen ",
  Cell[BoxData[
      \(TraditionalForm\`ArcTan[\ ]\)]],
  "-Ergebnissen ergibt nun bei der ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "-Implementierung keine Probleme mit dem Riemannschen Blatt:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(probe[4] = 
      \(\(\((x == erg[4] /. erg[1, 1])\) // FullSimplify\) // LogSimplify
          \) // Simplify\)], "Input"],

Cell[BoxData[
    \({True, 
      ArcTan[y] == 1\/2\ \((\[Pi] - I\ Log[\(-I\) + y] + I\ Log[I + y])\)}\)],
   "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(probe[5] = 
      \(\(\((x == erg[5] /. erg[1, 1])\) // FullSimplify\) // LogSimplify
          \) // Simplify\)], "Input"],

Cell[BoxData[
    \({True, 
      ArcTan[y] == 
        1\/2\ \((\[Pi] + I\ Log[\(-1\) + I\ y] - I\ Log[1 + I\ y])\)}\)], 
  "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(probe[6] = 
      \(\(\((x == erg[6] /. erg[1, 1])\) // FullSimplify\) // LogSimplify
          \) // Simplify\)], "Input"],

Cell[BoxData[
    \({True, 
      ArcTan[y] == 1\/4\ \((\[Pi] - 2\ I\ Log[1 + I\ y] + 2\ I\ Log[I + y])\)}
      \)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(probe[7] = 
      \(\((x == erg[7] /. erg[1, 1])\) // Simplify\) // LogSimplify\)], 
  "Input"],

Cell[BoxData[
    \({True, ArcTan[y] == \(-\(1\/2\)\)\ I\ Log[\(I - y\)\/\(I + y\)]}\)], 
  "Output"]
}, Open  ]],

Cell["\<\
Diese Probe schafft Klarheit! Sie demonstriert an einem Beispiel, da\[SZ] die \
bekannten Rechenregeln auch f\[UDoubleDot]r komplexe Zahlen gelten und \
eingesetzt werden k\[ODoubleDot]nnen.\
\>", "Text"],

Cell[TextData[{
  "Au\[SZ]erdem sind eine Reihe interessanter Indentit\[ADoubleDot]ten zur ",
  Cell[BoxData[
      \(TraditionalForm\`ArcTan[\ ]\)]],
  "-Funktion ermittelt, die sich bislang nicht in den g\[ADoubleDot]ngigen \
mathematischen Nachschlagewerken finden? Bei richtiger Bedienung k\
\[ODoubleDot]nnen derartige Zusammenh\[ADoubleDot]nge mit ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " gefunden, gepr\[UDoubleDot]ft und vertieft werden."
}], "Text"],

Cell[TextData[{
  "Die f\[UDoubleDot]r Lehrzwecke hilfreiche Formulierung der analytischen ",
  Cell[BoxData[
      \(TraditionalForm\`ArcTan[\ ]\)]],
  "-Funktion lautet:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(didaktisch\)], "Input"],

Cell[BoxData[
    \({I\ Log[\@\(\(I + y\)\/\(I - y\)\)], 
      1\/2\ I\ Log[\(I + y\)\/\(I - y\)], 
      \(-\(1\/2\)\)\ I\ Log[\(\(-I\) + y\)\/\(\(-I\) - y\)]}\)], "Output"]
}, Open  ]],

Cell["\<\
Diese drei Formeln lassen sich bei Verwendung der erweiterten \
Wurzel-Nomenklatur (siehe oben) zu einer einzigen zusammenfassen.\
\>", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ". Weitere Zusammenh\[ADoubleDot]nge"
}], "Subsection"],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". ",
  "Herleitung trigonometrischer Zusammenh\[ADoubleDot]nge"
}], "Subsubsection"],

Cell[TextData[{
  "Die gefundene komplexwertige Darstellung der ",
  Cell[BoxData[
      \(TraditionalForm\`ArcTan[\ ]\)]],
  "-Funktion zeigt, wie entsprechende trigonometrische Theoreme auf \
elementare Rechnung zur\[UDoubleDot]ckgef\[UDoubleDot]hrt werden k\
\[ODoubleDot]nnen (auch automatisiert):"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(theoreme[1] = \({Cos[#], Sin[#], Tan[#], Cot[#]}&\)/@didaktisch\)], 
  "Input"],

Cell[BoxData[
    \({{\(1 + \(I + y\)\/\(I - y\)\)\/\(2\ \@\(\(I + y\)\/\(I - y\)\)\), 
        \(I\ \((\(-1\) + \(I + y\)\/\(I - y\))\)\)\/\(2\ 
            \@\(\(I + y\)\/\(I - y\)\)\), 
        \(I\ \((\(-1\) + \(I + y\)\/\(I - y\))\)\)\/\(1 + 
            \(I + y\)\/\(I - y\)\), 
        \(-\(\(I\ \((1 + \(I + y\)\/\(I - y\))\)\)\/\(\(-1\) + 
                \(I + y\)\/\(I - y\)\)\)\)}, {
        Cosh[1\/2\ Log[\(I + y\)\/\(I - y\)]], 
        I\ Sinh[1\/2\ Log[\(I + y\)\/\(I - y\)]], 
        I\ Tanh[1\/2\ Log[\(I + y\)\/\(I - y\)]], 
        \(-I\)\ Coth[1\/2\ Log[\(I + y\)\/\(I - y\)]]}, {
        Cosh[1\/2\ Log[\(\(-I\) + y\)\/\(\(-I\) - y\)]], 
        \(-I\)\ Sinh[1\/2\ Log[\(\(-I\) + y\)\/\(\(-I\) - y\)]], 
        \(-I\)\ Tanh[1\/2\ Log[\(\(-I\) + y\)\/\(\(-I\) - y\)]], 
        I\ Coth[1\/2\ Log[\(\(-I\) + y\)\/\(\(-I\) - y\)]]}}\)], "Output"]
}, Open  ]],

Cell["\<\
Die Umwandlung in hyperbolische Funktionen ist hier eher von formalem \
Interesse, aber lehrreich:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(theoreme[1, 2] = 
      \(\(theoreme[1] // LogSimplify\) // PowerExpand\) // Simplify\)], 
  "Input"],

Cell[BoxData[
    \({{I\/\(\@\(I - y\)\ \@\(I + y\)\), 
        \(I\ y\)\/\(\@\(I - y\)\ \@\(I + y\)\), y, 1\/y}, {
        I\/\(\@\(I - y\)\ \@\(I + y\)\), 
        \(I\ y\)\/\(\@\(I - y\)\ \@\(I + y\)\), y, 1\/y}, {
        \(-\(I\/\(\@\(\(-I\) - y\)\ \@\(\( - I\) + y\)\)\)\), 
        \(-\(\(I\ y\)\/\(\@\(\(-I\) - y\)\ \@\(\( - I\) + y\)\)\)\), y, 1\/y}}
      \)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Die noch verbleibenden Restprobleme der Rechnung reduzieren sich auf das \
Produkt zweier Wurzeln, das bei ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " explizit \[UDoubleDot]ber eine eigene ",
  Cell[BoxData[
      \(TraditionalForm\`TimesRule\)]],
  " vereinfacht werden mu\[SZ]:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(theoreme[1, 3] = theoreme[1, 2] /. TimesRule // Union\)], "Input"],

Cell[BoxData[
    \({{\(-\(I\/\@\(\(-1\) - y\^2\)\)\), 
        \(-\(\(I\ y\)\/\@\(\(-1\) - y\^2\)\)\), y, 1\/y}, {
        I\/\@\(\(-1\) - y\^2\), \(I\ y\)\/\@\(\(-1\) - y\^2\), y, 1\/y}}\)], 
  "Output"]
}, Open  ]],

Cell[TextData[{
  "Diese Ergebnisse stimmen mit der Literatur (zum Beispiel ",
  ButtonBox["[GKHKR1974]",
    ButtonData:>"[GKHKR1974]",
    ButtonStyle->"Hyperlink"],
  ", Tabelle, Seite 278) \[UDoubleDot]berein, wobei sogar das alternierende \
Vorzeichen vor der Wurzel ber\[UDoubleDot]cksichtigt ist."
}], "Text"],

Cell[TextData[{
  "Es sei noch darauf hingewiesen, da\[SZ] die anderen Arcus-Funktionen aus \
dem ",
  Cell[BoxData[
      \(TraditionalForm\`ArcTan[\ ]\)]],
  " \[UDoubleDot]ber die angegebenen algebraischen Zusammenh\[ADoubleDot]nge \
beschrieben werden k\[ODoubleDot]nnen. Die elementare Funktion dazu hei\[SZ]t \
auch schon bei jedem BASIC ",
  Cell[BoxData[
      \(TraditionalForm\`ATN\)]],
  " und zeigt auch die Vorteile von FORTRAN auf, der ersten \
Programmiersprache, die das Rechnen mit komplexen Zahlen bereits standardm\
\[ADoubleDot]\[SZ]ig vorgesehen hat."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". ",
  "Ziehen ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "-ter Wurzeln"
}], "Subsubsection"],

Cell[TextData[{
  "Nach F. Vieta (vgl. ",
  ButtonBox["[GKHKR1974]",
    ButtonData:>"[GKHKR1974]",
    ButtonStyle->"Hyperlink"],
  ", Seite 110-111) ist sp\[ADoubleDot]testens ab etwa 1600 der ",
  StyleBox["casus irreducibilis",
    FontSlant->"Italic"],
  " bei kubischen Gleichungen ein Anla\[SZ], den ",
  Cell[BoxData[
      \(TraditionalForm\`ArcTan[\ ]\)]],
  " durch eine reelle Zahl zu teilen, wobei dadurch eine ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "-Teilung des zugeh\[ODoubleDot]rigen Winkels stattfindet. Auch Johann \
Faulhaber bringt 1604 durch sein Lehrwerk ",
  StyleBox["Arithmetisch-Cubiccosischer Lustgarten",
    FontSlant->"Italic"],
  " (86 Seiten, Stadtbibliothek Ulm 43210, Mikrofilm 23; zitiert nach ",
  ButtonBox["[Haw1995]",
    ButtonData:>"[Haw1995]",
    ButtonStyle->"Hyperlink"],
  ", Abschnitt 2.3, Seite 150) eine inhaltliche Beziehung dieser Art zum \
Ausdruck."
}], "Text"],

Cell[TextData[{
  "Kurz und gut: Die trigonometrischen Funktionen m\[UDoubleDot]ssen \
angewandt werden auf den ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "-ten Teil der ",
  Cell[BoxData[
      \(TraditionalForm\`ArcTan[\ ]\)]],
  "-Funktion. Nach der nun vollendeten logarithmischen Beschreibung ist \
dieses R\[ADoubleDot]tsel formal vollst\[ADoubleDot]ndig gel\[ODoubleDot]st:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ntewurzel = didaktisch\/n /. y \[Rule] z // LogSimplify\)], "Input"],

Cell[BoxData[
    \({I\ Log[\((\(I + z\)\/\(I - z\))\)\^\(1\/\(2\ n\)\)], 
      1\/2\ I\ Log[\((\(I + z\)\/\(I - z\))\)\^\(1\/n\)], 
      \(-\(1\/2\)\)\ I\ Log[\((\(\(-I\) + z\)\/\(\(-I\) - z\))\)\^\(1\/n\)]}
      \)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Die entsprechenden Wurzeln werden dem Argument der Logarithmus-Funktion \
mitgegeben. Formal ist dies eine Umkehrung in den ",
  StyleBox["casus irreducibilis",
    FontSlant->"Italic"],
  " und weitere rechentechnischen Schwierigkeiten. Wichtig ist vor allem die \
fachdidaktische Aufbereitung des Zusammenhangs."
}], "Text"],

Cell[TextData[{
  "Beim Ziehen einer ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "-ten Wurzel aus einer komplexen Zahl ",
  Cell[BoxData[
      \(TraditionalForm\`x + \[ImaginaryI]\ y\)]],
  " interessiert etwa der Betrag ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(x\^2 + y\^2\)\)]],
  " und freilich auch der Real- und Imagin\[ADoubleDot]rteil der Wurzel."
}], "Text"],

Cell[TextData[{
  "Der Realteil der Wurzel ist der Betrag multipliziert mit dem Cosinus des \
zugeh\[ODoubleDot]rigen Phasenwinkels, der Imagin\[ADoubleDot]rteil das \
Produkt aus Betrag und Sinus des Phasenwinkels. Der Phasenwinkel ",
  Cell[BoxData[
      \(TraditionalForm\`\[CurlyPhi] \[Equal] ArcTan[z \[Equal] y\/x]\)]],
  " ist mit der nun bekannten Formel alles, was zur formalen Bestimmung von \
Real- und Imagin\[ADoubleDot]rteil einer ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "-ten Wurzel wichtig ist:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(trigwurzeln[1] = 
      Simplify[\(\(\({Cos[#], \[ImaginaryI]\ Sin[#]}&\)/@ntewurzel /. 
                    z \[Rule] y\/x // LogSimplify\) // 
                MapAll[Together, #]&\) // PowerExpand] /. TimesRule // Union; 
    \nMatrixForm/@trigwurzeln[1] // TableForm\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      InterpretationBox[
        RowBox[{"(", GridBox[{
             
               {\(1\/2\ 
                  \((\((x - I\ y)\)\^\(1\/n\) + \((x + I\ y)\)\^\(1\/n\))\)\ 
                  \((x\^2 + y\^2)\)\^\(-\(1\/\(2\ n\)\)\)\)},
             
               {\(1\/2\ 
                  \((\(-\((x - I\ y)\)\^\(1\/n\)\) + \((x + I\ y)\)\^\(1\/n\))
                    \)\ \((x\^2 + y\^2)\)\^\(-\(1\/\(2\ n\)\)\)\)}
              }], ")"}],
        MatrixForm[ {
          Times[ 
            Rational[ 1, 2], 
            Plus[ 
              Power[ 
                Plus[ x, 
                  Times[ 
                    Complex[ 0, -1], y]], 
                Power[ n, -1]], 
              Power[ 
                Plus[ x, 
                  Times[ 
                    Complex[ 0, 1], y]], 
                Power[ n, -1]]], 
            Power[ 
              Plus[ 
                Power[ x, 2], 
                Power[ y, 2]], 
              Times[ 
                Rational[ -1, 2], 
                Power[ n, -1]]]], 
          Times[ 
            Rational[ 1, 2], 
            Plus[ 
              Times[ -1, 
                Power[ 
                  Plus[ x, 
                    Times[ 
                      Complex[ 0, -1], y]], 
                  Power[ n, -1]]], 
              Power[ 
                Plus[ x, 
                  Times[ 
                    Complex[ 0, 1], y]], 
                Power[ n, -1]]], 
            Power[ 
              Plus[ 
                Power[ x, 2], 
                Power[ y, 2]], 
              Times[ 
                Rational[ -1, 2], 
                Power[ n, -1]]]]}]],
      TableForm[ {
        MatrixForm[ {
          Times[ 
            Rational[ 1, 2], 
            Plus[ 
              Power[ 
                Plus[ x, 
                  Times[ 
                    Complex[ 0, -1], y]], 
                Power[ n, -1]], 
              Power[ 
                Plus[ x, 
                  Times[ 
                    Complex[ 0, 1], y]], 
                Power[ n, -1]]], 
            Power[ 
              Plus[ 
                Power[ x, 2], 
                Power[ y, 2]], 
              Times[ 
                Rational[ -1, 2], 
                Power[ n, -1]]]], 
          Times[ 
            Rational[ 1, 2], 
            Plus[ 
              Times[ -1, 
                Power[ 
                  Plus[ x, 
                    Times[ 
                      Complex[ 0, -1], y]], 
                  Power[ n, -1]]], 
              Power[ 
                Plus[ x, 
                  Times[ 
                    Complex[ 0, 1], y]], 
                Power[ n, -1]]], 
            Power[ 
              Plus[ 
                Power[ x, 2], 
                Power[ y, 2]], 
              Times[ 
                Rational[ -1, 2], 
                Power[ n, -1]]]]}]}]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Die ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "-te Wurzel einer komplexen Zahl besteht aus dem Realteil dieser Wurzel \
plus ",
  Cell[BoxData[
      \(TraditionalForm\`\[ImaginaryI]\)]],
  " mal dem Imagin\[ADoubleDot]rteil derselben."
}], "Text"],

Cell["\<\
Der Realteil besteht aus dem arithmetischen Mittel von Wurzel und konjugiert \
komplexer Wurzel, beim Imagin\[ADoubleDot]rteil ist eine Differenz zu bilden. \
Dieses Ergebnis rundet anschaulich ab, da\[SZ] Potenzen aus komplexen Zahlen \
wieder komplexe Zahlen sind.\
\>", "Text"],

Cell[TextData[{
  "Werden auch komplexzahlige Wurzel-Ordnungen ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " zugelassen, so wird ein Produkt aus Real-Potenz und \
Imagin\[ADoubleDot]r-Potenz gebildet, wobei die Grundeinsicht"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((a + \[ImaginaryI]\ b)\)\^\(x + \[ImaginaryI]\ y\) // ComplexExpand
      \)], "Input"],

Cell[BoxData[
    \(E\^\(\(-y\)\ Arg[a + I\ b]\)\ Abs[a + I\ b]\^x\ 
        Cos[x\ Arg[a + I\ b] + y\ Log[Abs[a + I\ b]]] + 
      I\ E\^\(\(-y\)\ Arg[a + I\ b]\)\ Abs[a + I\ b]\^x\ 
        Sin[x\ Arg[a + I\ b] + y\ Log[Abs[a + I\ b]]]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "bestehen bleibt. Falls ",
  Cell[BoxData[
      \(TraditionalForm\`{a, b, x, y} \[Element] \[DoubleStruckCapitalR]\)]],
  " gilt, so vereinfacht sich ",
  Cell[BoxData[
      \(TraditionalForm\`Arg[a + \[ImaginaryI]\ b] \[Rule] ArcTan[b\/a]\)]],
  ", und der Logarithmus aus einer komplexen Zahl mu\[SZ] in seiner \
Mehrdeutigkeit bez\[UDoubleDot]glich der Riemannschen Bl\[ADoubleDot]tter \
beachtet werden. Das Ergebnis der Operation ist eine komplexe Zahl. Sind ",
  Cell[BoxData[
      \(TraditionalForm\`{a, b, x, y}\)]],
  " komplex, so lassen sie sich stets auf ein reelles dazu passendes \
Alternativ-Quadrupel reduzieren."
}], "Text"],

Cell["Folgender Satz resultiert:", "Text"],

Cell["\<\
Ist die komplex konjugierte Funktion einer komplexen Zahl
gleich der Funktion der konjugiert komplexen Zahl,
so l\[ADoubleDot]\[SZ]t sich eine rechentechnische Separation
von Real- und Imagin\[ADoubleDot]rteil der Funktion erreichen,
selbst wenn der konkrete Aufbau der Funktion unbekannt bleibt.\
\>", "Text",
  TextAlignment->Center,
  FontSlant->"Italic"],

Cell["\<\
Auf diese Weise k\[ODoubleDot]nnen alle komplexen Potenzen komplexer Zahlen \
verstanden werden. Analytische Funktionen komplexer Zahlen, die diese \
Eigenschaft nicht besitzen, sind gar nicht so einfach formulierbar.\
\>", "Text"],

Cell[TextData[{
  "Bei ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " gibt die Realteilfunktion ",
  Cell[BoxData[
      \(TraditionalForm\`Re[\ ]\)]],
  " und die Imagin\[ADoubleDot]rteilfunktion ",
  Cell[BoxData[
      \(TraditionalForm\`Im[\ ]\)]],
  " f\[UDoubleDot]r ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "-ten Wurzeln keine Umwandlung in eine Summe oder Differenz konjugiert \
komplexer Wurzeln an, da die Numerik beider Terme leicht verschiedene Betr\
\[ADoubleDot]ge ergibt und somit die klare Trennung in Real- und Imagin\
\[ADoubleDot]rteil verweigert. Die Asymmetrie der Numerik ist durch das Bin\
\[ADoubleDot]rsystem bedingt und inhaltlich sinnvoll, da die effektive \
Rechengenauigkeit stets me\[SZ]bar bleibt. Eine Regel zur automatischen \
Erkennung von ",
  Cell[BoxData[
      \(TraditionalForm\`Re[\ ]\)]],
  " und ",
  Cell[BoxData[
      \(TraditionalForm\`Im[\ ]\)]],
  " bei Potenztermen existiert leider bislang nicht, was noch \
erg\[ADoubleDot]nzt werden sollte, um die zugeh\[ODoubleDot]rige Numerik f\
\[UDoubleDot]r ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "-Proben zu verbessern."
}], "Text"],

Cell["\<\
Die Einsicht von Gau\[SZ], da\[SZ] die Siebenteilung des Winkels identisch \
mit der L\[ODoubleDot]sung einer Gleichung siebten Grades ist, wird auch auf \
diese Weise best\[ADoubleDot]tigt.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". ",
  "Wesen und Bedeutung der Primzahlen"
}], "Subsubsection"],

Cell[TextData[{
  "Nun soll noch gezeigt werden, da\[SZ] beim Ziehen ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "-ter Wurzeln nur die Wurzeln einer Primzahl-Ordnung \
eigenst\[ADoubleDot]ndig sind, da alle anderen nat\[UDoubleDot]rlichen \
Wurzeln einer komplexen Zahl durch Iteration eindeutig gezogen werden k\
\[ODoubleDot]nnen."
}], "Text"],

Cell["\<\
F\[UDoubleDot]r quadratische Gleichungen existiert eine eindeutige L\
\[ODoubleDot]sung, die nur einen einzigen Wurzelterm beinhaltet. Aus diesem \
Grunde kann der Realteil und Imagin\[ADoubleDot]rteil der Quadratwurzeln klar \
getrennt werden. Die geometrische Konstruktion zur Halbierung eines \
beliebigen Winkels existiert ebenfalls.\
\>", "Text"],

Cell["Eine Herleitung dieses Zusammenhang mag die folgende sein:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(problem = 
      MapIndexed[
        \((\@\(a + b\) + \(\((\(-1\))\)\^First[#2]\) \@\(a - b\) == #1)\)&, {
          A, B}]; \nproblem // MatrixForm\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", GridBox[{
            {\(\(-\@\(a - b\)\) + \@\(a + b\) == A\)},
            {\(\@\(a - b\) + \@\(a + b\) == B\)}
            }], ")"}],
      MatrixForm[ {
        Equal[ 
          Plus[ 
            Times[ -1, 
              Power[ 
                Plus[ a, 
                  Times[ -1, b]], 
                Rational[ 1, 2]]], 
            Power[ 
              Plus[ a, b], 
              Rational[ 1, 2]]], A], 
        Equal[ 
          Plus[ 
            Power[ 
              Plus[ a, 
                Times[ -1, b]], 
              Rational[ 1, 2]], 
            Power[ 
              Plus[ a, b], 
              Rational[ 1, 2]]], B]}]]], "Output"]
}, Open  ]],

Cell["\<\
Ein Quadrieren der beiden Gleichungen in der angegebenen Stellung ergibt:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(quadrat = ExpandAll[Map[#\^2&, problem, {2}]] /. TimesRule; \n
    quadrat // MatrixForm\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", GridBox[{
            {\(2\ a - 2\ \@\(a\^2 - b\^2\) == A\^2\)},
            {\(2\ a + 2\ \@\(a\^2 - b\^2\) == B\^2\)}
            }], ")"}],
      MatrixForm[ {
        Equal[ 
          Plus[ 
            Times[ 2, a], 
            Times[ -2, 
              Power[ 
                Plus[ 
                  Power[ a, 2], 
                  Times[ -1, 
                    Power[ b, 2]]], 
                Rational[ 1, 2]]]], 
          Power[ A, 2]], 
        Equal[ 
          Plus[ 
            Times[ 2, a], 
            Times[ 2, 
              Power[ 
                Plus[ 
                  Power[ a, 2], 
                  Times[ -1, 
                    Power[ b, 2]]], 
                Rational[ 1, 2]]]], 
          Power[ B, 2]]}]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Durch Subtraktion von ",
  Cell[BoxData[
      \(TraditionalForm\`2  a\)]],
  " bei beiden Gleichungen und anschlie\[SZ]endes Quadrieren ergibt sich:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(bestimmungsgleichung = 
      Map[#\^2&, Map[# - 2  a&, quadrat, {2}], {2}] // Simplify; \n
    bestimmungsgleichung // MatrixForm\)], "Input"],

Cell[BoxData[
    InterpretationBox[
      RowBox[{"(", GridBox[{
            {\(4\ a\ A\^2 - A\^4 - 4\ b\^2 == 0\)},
            {\(\(-4\)\ b\^2 + 4\ a\ B\^2 - B\^4 == 0\)}
            }], ")"}],
      MatrixForm[ {
        Equal[ 
          Plus[ 
            Times[ 4, a, 
              Power[ A, 2]], 
            Times[ -1, 
              Power[ A, 4]], 
            Times[ -4, 
              Power[ b, 2]]], 0], 
        Equal[ 
          Plus[ 
            Times[ -4, 
              Power[ b, 2]], 
            Times[ 4, a, 
              Power[ B, 2]], 
            Times[ -1, 
              Power[ B, 4]]], 0]}]]], "Output"]
}, Open  ]],

Cell["\<\
Diese biquadratischen Gleichungen k\[ODoubleDot]nnen formal \
gel\[ODoubleDot]st werden, wobei eine Proberechnung \
unerl\[ADoubleDot]\[SZ]lich ist:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(formall\[ODoubleDot]sung = 
      MapThread[Solve[#1, #2]&, {bestimmungsgleichung, {A, B}}]; \n
    Transpose[formall\[ODoubleDot]sung] // TableForm\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(A \[Rule] \(-I\)\ \@2\ \@\(\( - a\) + \@\(a\^2 - b\^2\)\)\), 
            \(B \[Rule] \(-I\)\ \@2\ \@\(\( - a\) + \@\(a\^2 - b\^2\)\)\)},
          {\(A \[Rule] I\ \@2\ \@\(\( - a\) + \@\(a\^2 - b\^2\)\)\), 
            \(B \[Rule] I\ \@2\ \@\(\( - a\) + \@\(a\^2 - b\^2\)\)\)},
          {\(A \[Rule] \(-\@2\)\ \@\(a + \@\(a\^2 - b\^2\)\)\), 
            \(B \[Rule] \(-\@2\)\ \@\(a + \@\(a\^2 - b\^2\)\)\)},
          {\(A \[Rule] \@2\ \@\(a + \@\(a\^2 - b\^2\)\)\), 
            \(B \[Rule] \@2\ \@\(a + \@\(a\^2 - b\^2\)\)\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{{A -> Times[ 
          Complex[ 0, -1], 
          Power[ 2, 
            Rational[ 1, 2]], 
          Power[ 
            Plus[ 
              Times[ -1, a], 
              Power[ 
                Plus[ 
                  Power[ a, 2], 
                  Times[ -1, 
                    Power[ b, 2]]], 
                Rational[ 1, 2]]], 
            Rational[ 1, 2]]]}, {B -> Times[ 
          Complex[ 0, -1], 
          Power[ 2, 
            Rational[ 1, 2]], 
          Power[ 
            Plus[ 
              Times[ -1, a], 
              Power[ 
                Plus[ 
                  Power[ a, 2], 
                  Times[ -1, 
                    Power[ b, 2]]], 
                Rational[ 1, 2]]], 
            Rational[ 1, 2]]]}}, {{A -> Times[ 
          Complex[ 0, 1], 
          Power[ 2, 
            Rational[ 1, 2]], 
          Power[ 
            Plus[ 
              Times[ -1, a], 
              Power[ 
                Plus[ 
                  Power[ a, 2], 
                  Times[ -1, 
                    Power[ b, 2]]], 
                Rational[ 1, 2]]], 
            Rational[ 1, 2]]]}, {B -> Times[ 
          Complex[ 0, 1], 
          Power[ 2, 
            Rational[ 1, 2]], 
          Power[ 
            Plus[ 
              Times[ -1, a], 
              Power[ 
                Plus[ 
                  Power[ a, 2], 
                  Times[ -1, 
                    Power[ b, 2]]], 
                Rational[ 1, 2]]], 
            Rational[ 1, 2]]]}}, {{A -> Times[ -1, 
          Power[ 2, 
            Rational[ 1, 2]], 
          Power[ 
            Plus[ a, 
              Power[ 
                Plus[ 
                  Power[ a, 2], 
                  Times[ -1, 
                    Power[ b, 2]]], 
                Rational[ 1, 2]]], 
            Rational[ 1, 2]]]}, {B -> Times[ -1, 
          Power[ 2, 
            Rational[ 1, 2]], 
          Power[ 
            Plus[ a, 
              Power[ 
                Plus[ 
                  Power[ a, 2], 
                  Times[ -1, 
                    Power[ b, 2]]], 
                Rational[ 1, 2]]], 
            Rational[ 1, 2]]]}}, {{A -> Times[ 
          Power[ 2, 
            Rational[ 1, 2]], 
          Power[ 
            Plus[ a, 
              Power[ 
                Plus[ 
                  Power[ a, 2], 
                  Times[ -1, 
                    Power[ b, 2]]], 
                Rational[ 1, 2]]], 
            Rational[ 1, 2]]]}, {B -> Times[ 
          Power[ 2, 
            Rational[ 1, 2]], 
          Power[ 
            Plus[ a, 
              Power[ 
                Plus[ 
                  Power[ a, 2], 
                  Times[ -1, 
                    Power[ b, 2]]], 
                Rational[ 1, 2]]], 
            Rational[ 1, 2]]]}}}]]], "Output"]
}, Open  ]],

Cell["\<\
Alle vier L\[ODoubleDot]sungen sind paarweise identisch. Allein dies zeigt \
schon die Notwendigkeit der Probe:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(probe = 
      ExpandAll[
            Map[#\^2&, 
              \((problem /. Flatten/@Transpose[formall\[ODoubleDot]sung])\), {
                3}]] /. TimesRule // Simplify; \nprobe // TableForm\)], 
  "Input"],

Cell[BoxData[
    TagBox[GridBox[{
          {"True", \(4\ \@\(a\^2 - b\^2\) == 0\)},
          {"True", \(4\ \@\(a\^2 - b\^2\) == 0\)},
          {\(\(-4\)\ \@\(a\^2 - b\^2\) == 0\), "True"},
          {\(\(-4\)\ \@\(a\^2 - b\^2\) == 0\), "True"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      (TableForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Die unabh\[ADoubleDot]ngig von den Parametern ",
  Cell[BoxData[
      \(TraditionalForm\`{a, b}\)]],
  " best\[ADoubleDot]tigten L\[ODoubleDot]sungen der Probe werden \
zusammengefa\[SZ]t:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(quadratl\[ODoubleDot]sung = 
      \({Take[First[#], 2], Take[Last[#], \(-2\)]}&\)@
        formall\[ODoubleDot]sung; \n
    \(quadratl\[ODoubleDot]sung // Transpose\) // TableForm\)], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(A \[Rule] \(-I\)\ \@2\ \@\(\( - a\) + \@\(a\^2 - b\^2\)\)\), 
            \(B \[Rule] \(-\@2\)\ \@\(a + \@\(a\^2 - b\^2\)\)\)},
          {\(A \[Rule] I\ \@2\ \@\(\( - a\) + \@\(a\^2 - b\^2\)\)\), 
            \(B \[Rule] \@2\ \@\(a + \@\(a\^2 - b\^2\)\)\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {{{A -> Times[ 
          Complex[ 0, -1], 
          Power[ 2, 
            Rational[ 1, 2]], 
          Power[ 
            Plus[ 
              Times[ -1, a], 
              Power[ 
                Plus[ 
                  Power[ a, 2], 
                  Times[ -1, 
                    Power[ b, 2]]], 
                Rational[ 1, 2]]], 
            Rational[ 1, 2]]]}, {B -> Times[ -1, 
          Power[ 2, 
            Rational[ 1, 2]], 
          Power[ 
            Plus[ a, 
              Power[ 
                Plus[ 
                  Power[ a, 2], 
                  Times[ -1, 
                    Power[ b, 2]]], 
                Rational[ 1, 2]]], 
            Rational[ 1, 2]]]}}, {{A -> Times[ 
          Complex[ 0, 1], 
          Power[ 2, 
            Rational[ 1, 2]], 
          Power[ 
            Plus[ 
              Times[ -1, a], 
              Power[ 
                Plus[ 
                  Power[ a, 2], 
                  Times[ -1, 
                    Power[ b, 2]]], 
                Rational[ 1, 2]]], 
            Rational[ 1, 2]]]}, {B -> Times[ 
          Power[ 2, 
            Rational[ 1, 2]], 
          Power[ 
            Plus[ a, 
              Power[ 
                Plus[ 
                  Power[ a, 2], 
                  Times[ -1, 
                    Power[ b, 2]]], 
                Rational[ 1, 2]]], 
            Rational[ 1, 2]]]}}}]]], "Output"]
}, Open  ]],

Cell["\<\
Die einh\[UDoubleDot]llende Quadratwurzel besitzt jeweils ein alternierendes \
Vorzeichen, das \[UDoubleDot]ber eine Quadratur best\[ADoubleDot]tigt wird \
und deshalb unerheblich ist. Das positive Vorzeichen vor der Wurzel ist im \
Zweifelsfall die korrekte Lehrbuchdarstellung.\
\>", "Text"],

Cell[TextData[{
  "Somit sind folgende Wurzel-Theoreme f\[UDoubleDot]r alle ",
  Cell[BoxData[
      \(TraditionalForm\`{a, b, x, y} \[Element] \[DoubleStruckCapitalC]\)]],
  " bewiesen: "
}], "Text"],

Cell[BoxData[{
    \(\@\(a + b\) \[PlusMinus] \@\(a - b\) == 
      \@\(2  a \[PlusMinus] 2 \@\( a\^2 - b\^2\)\) == 
      \@\(2  a \((1 \[PlusMinus] \@\(1 - \((b\/a)\)\^2\))\)\)\), 
    \(\@\(x \[PlusMinus] \@y\) == 
      \@\(x\/2 + \@\(x\^2\/4 - y\/4\)\) \[PlusMinus] 
        \@\(x\/2 - \@\(x\^2\/4 - y\/4\)\)\), 
    \(\@\(x \[PlusMinus] \[ImaginaryI]\ y\) == 
      \@\(\(\@\(x\^2 + y\^2\) + x\)\/2\) \[PlusMinus] 
        \[ImaginaryI]\ \@\(\(\@\(x\^2 + y\^2\) - x\)\/2\)\), 
    \(\@\(x + \[ImaginaryI]\ y\) \[PlusMinus] \@\(x - \[ImaginaryI]\ y\) == 
      \@\(2  x \[PlusMinus] 2 \@\( x\^2 + y\^2\)\) == 
      \@\(2  x \((1 \[PlusMinus] \@\(1 + \((y\/x)\)\^2\))\)\)\)}], 
  "NumberedEquation",
  CellTags->"Quadratwurzeln"],

Cell[TextData[
"Die geschachtelte Verwendung des Quadratwurzelzeichens deutet an, da\[SZ] \
eine Darstellung ohne diese Schachtelung existiert \[Dash] allerdings dann \
mit komplexen Zahlenwerten. Die Schachtelung der Wurzeln vertieft sich bei \
entsprechender Addition mit geschachtelten Wurzeln."], "Text"],

Cell[TextData[{
  "Durch iterierte Anwendung dieses Zusammenhangs (",
  CounterBox["Title"],
  ".",
  CounterBox["NumberedEquation", "Quadratwurzeln"],
  ") ",
  "ergibt sich zum Beispiel die vierte Wurzel einer komplexen Zahl wie \
folgt:"
}], "Text"],

Cell[BoxData[
    \(\(\@\(x \[PlusMinus] \[ImaginaryI]\ y\)\%4 = 
      \(\@\(\@\(\(\@\(x\^2 + y\^2\) + x\)\/2\) \[PlusMinus] 
            \[ImaginaryI]\ \@\(\(\@\(x\^2 + y\^2\) - x\)\/2\)\) = \n\t
        \@\(\(\@\(x\^2 + y\^2\)\%4 + \@\(\(x + \@\(x\^2 + y\^2\)\)\/2\)\)\/2
                \) \[PlusMinus] 
          \[ImaginaryI] 
            \@\(\(\@\( x\^2 + y\^2\)\%4 - 
                    \@\(\(x + \@\(x\^2 + y\^2\)\)\/2\)\)\/2\)\)\t\)\)], 
  "NumberedEquation"],

Cell["\<\
Eine Vierfachsumme aus vierten Wurzeln unter der Qudratwurzel ist auch m\
\[ODoubleDot]glich.\
\>", "Text"],

Cell[TextData[{
  "Die Wurzel aus einer komplexen Zahl taucht normalerweise bei Gleichungen \
vierten Grades mit reellen Koeffizienten zuerst auf, so da\[SZ] analog dazu \
die vierte Wurzel aus einer komplexen Zahl zu einer Gleichung achten Grades \
mit reellen Koeffizienten geh\[ODoubleDot]rt. Der Charakter ",
  Cell[BoxData[
      \(TraditionalForm\`\[ImaginaryI]\^2 \[Equal] \(-1\)\)]],
  " unterstreicht diesen Zusammenhang."
}], "Text"],

Cell[TextData[{
  "Sind die Terme ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " und ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " jeweils komplexe Zahlen, so ergibt sich eine andere Aufspaltung von Real- \
und Imagin\[ADoubleDot]rteil, woraus ein allgemeines Theorem zur ",
  Cell[BoxData[
      \(TraditionalForm\`2  n\)]],
  "-ten Wurzel aus zwei komplexen Zahlen f\[UDoubleDot]r ",
  Cell[BoxData[
      \(TraditionalForm\`n \[Element] \[DoubleStruckCapitalN]\)]],
  " herleitbar ist."
}], "Text"],

Cell["\<\
Damit ist gezeigt, da\[SZ] nur die Wurzeln mit einer Primzahl-Ordnung auch \
\"prim\[ADoubleDot]r\" sind. Die Unendlichkeit der Primzahlen \
f\[UDoubleDot]hrt zu einem unersch\[ODoubleDot]pflichen Vorrat an \
Fragestellungen zur analytischen Mathematik.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ".",
  CounterBox["Subsection"],
  ".",
  CounterBox["Subsubsection"],
  ". Ausblick in die Musiktheorie"
}], "Subsubsection"],

Cell[TextData[{
  "Bei ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " ist eine besonders h\[UDoubleDot]bsche Z\[ADoubleDot]hlung der Primzahlen \
vorhanden:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(?Prime\)\)], "Input"],

Cell[BoxData[
    \("Prime[n] gives the nth prime number."\)], "Print"]
}, Open  ]],

Cell[TextData[{
  "Je nach Definition ist ",
  Cell[BoxData[
      \(TraditionalForm\`1\)]],
  " positiv sowie nur noch durch Eins und sich selbst teilbar. Deshalb \
erscheint es sinnvoll, im Sinne der Wolframschen Z\[ADoubleDot]hlung die \
Definition der Primzahlen zu erweitern:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(Function[\n\t (************) \n\t\t
        Prime[0] := \n\t (************) \n\t1\ ; \n\n\tProtect[#]\n]\)[
      Unprotect[Prime]]\t\)\)], "Input"],

Cell[BoxData[
    \({"Prime"}\)], "Output"]
}, Open  ]],

Cell["\<\
Daraus folgt die Einsicht, da\[SZ] die ersten vierzehn Primzahlen die \
folgenden sind:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Prime[7  # + Range[0, 6]]&\)/@Range[0, 2] // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {"1", "2", "3", "5", "7", "11", "13"},
            {"17", "19", "23", "29", "31", "37", "41"},
            {"43", "47", "53", "59", "61", "67", "71"}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Die Wolframsche Z\[ADoubleDot]hlweise (",
  ButtonBox["[Wol1997]",
    ButtonData:>"[Wol1997]",
    ButtonStyle->"Hyperlink"],
  ", Abschnitt 3.2.4, Seite 781), die mit der griechischen Philosophie \
korreliert, hat auch ihren Sinn:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Prime[13]\)], "Input"],

Cell[BoxData[
    \(41\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Dies ist bei Siebener-Rhythmen die einzige M\[ODoubleDot]glichkeit, durch \
den \"Wochen\"-Abschlu\[SZ] der einen auf den Abschlu\[SZ] der folgenden \
\"Woche\" zu schlie\[SZ]en. Die Siebener-Listen haben im Zusammenhang mit \
Primzahlen durchaus Sinn: Ein Algorithmus zur Errechnung der ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "-ten Primzahl ben\[ODoubleDot]tigt zum Beispiel ein Sieb aus ",
  Cell[BoxData[
      \(TraditionalForm\`14\)]],
  " durchgek\[UDoubleDot]rzten Br\[UDoubleDot]chen (",
  ButtonBox["[Oli1995]",
    ButtonData:>"[Oli1995]",
    ButtonStyle->"Hyperlink"],
  ", Seite 30-38) in zwei Reihen."
}], "Text"],

Cell[TextData[{
  "Die ",
  Cell[BoxData[
      \(TraditionalForm\`41\)]],
  "-te Wurzel aus Zwei spielt in der musikalischen Harmonielehre eine \
besondere Rolle, da die entsprechend gleichschwebend gestimmten Intervalle"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(intervalle[41] = 
      2\^\({{0, 3, 6, 7, 8, 9, 11, 13, 17, 20}, 
                Reverse[{21, 24, 28, 30, 32, 33, 34, 35, 38, 41}]}\/41\) // 
        N; \n\(intervalle[41] // N[#, 5]&\) // MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", GridBox[{
            {
              StyleBox["1.`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5], 
              StyleBox["1.05202627094241507`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5], 
              StyleBox["1.10675927475300395`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5], 
              StyleBox["1.12562923754815646`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5], 
              StyleBox["1.14482092838662707`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5], 
              StyleBox["1.16433983264933482`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5], 
              StyleBox["1.20438169218741708`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5], 
              StyleBox["1.24580059858957459`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5], 
              StyleBox["1.33296060817114137`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5], 
              StyleBox["1.40230957792741968`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5]},
            {
              StyleBox["2.`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5], 
              StyleBox["1.90109320959103396`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5], 
              StyleBox["1.80707769577656698`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5], 
              StyleBox["1.77678398293597901`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5], 
              StyleBox["1.74699811158987294`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5], 
              StyleBox["1.71771156832211957`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5], 
              StyleBox["1.66060312355593131`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5], 
              StyleBox["1.60539335288832791`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5], 
              StyleBox["1.50041943305740899`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5], 
              StyleBox["1.42621859786193239`",
                StyleBoxAutoDelete->True,
                PrintPrecision->5]}
            }], ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  "extrem reine und harmonische Kl\[ADoubleDot]nge erm\[ODoubleDot]glichen \
\[Dash] unter anderem auch harmonische Vierkl\[ADoubleDot]nge ",
  ButtonBox["[SRGT1993]",
    ButtonData:>"[SRGT1993]",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(intervallzuordnung[41] = 
      \({#, Rationalize[#, 1\/100], 
            1200 \( Log[#/Rationalize[#, 1\/100]]\/Log[2]\) "\<Cent\>" // N}&
          \)/@intervalle[41]; \n
    MatrixForm/@\(Transpose/@intervallzuordnung[41]\)\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          RowBox[{"(", GridBox[{
                {"1.`", "1", \(0.`\ "Cent"\)},
               
                 {"1.05202627094241507`", \(20\/19\), 
                  \(\(-0.995819683751693496`\)\ "Cent"\)},
               
                 {"1.10675927475300395`", \(10\/9\), 
                  \(\(-6.79395603649854074`\)\ "Cent"\)},
               
                 {"1.12562923754815646`", \(9\/8\), 
                  \(0.968047049713360685`\ "Cent"\)},
               
                 {"1.14482092838662707`", \(8\/7\), 
                  \(2.97224793253998029`\ "Cent"\)},
               
                 {"1.16433983264933482`", \(7\/6\), 
                  \(\(-3.45627145739527597`\)\ "Cent"\)},
               
                 {"1.20438169218741708`", \(6\/5\), 
                  \(6.30993251164316593`\ "Cent"\)},
               
                 {"1.24580059858957459`", \(5\/4\), 
                  \(\(-5.82590898678522606`\)\ "Cent"\)},
               
                 {"1.33296060817114137`", \(4\/3\), 
                  \(\(-0.484023524855477482`\)\ "Cent"\)},
               
                 {"1.40230957792741968`", \(7\/5\), 
                  \(2.85366105424768399`\ "Cent"\)}
                }], ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"2.`", "2", \(0.`\ "Cent"\)},
               
                 {"1.90109320959103396`", \(19\/10\), 
                  \(0.995819683754090156`\ "Cent"\)},
               
                 {"1.80707769577656698`", \(9\/5\), 
                  \(6.7939560365012781`\ "Cent"\)},
               
                 {"1.77678398293597901`", \(16\/9\), 
                  \(\(-0.968047049710899898`\)\ "Cent"\)},
               
                 {"1.74699811158987294`", \(7\/4\), 
                  \(\(-2.97224793253778898`\)\ "Cent"\)},
               
                 {"1.71771156832211957`", \(12\/7\), 
                  \(3.45627145739807728`\ "Cent"\)},
               
                 {"1.66060312355593131`", \(5\/3\), 
                  \(\(-6.30993251164077761`\)\ "Cent"\)},
               
                 {"1.60539335288832791`", \(8\/5\), 
                  \(5.82590898678800606`\ "Cent"\)},
               
                 {"1.50041943305740899`", \(3\/2\), 
                  \(0.484023524857968023`\ "Cent"\)},
               
                 {"1.42621859786193239`", \(10\/7\), 
                  \(\(-2.85366105424528004`\)\ "Cent"\)}
                }], ")"}],
          (MatrixForm[ #]&)]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Die Angabe zur Abweichung der Intervalle von den reinen Frequenzverh\
\[ADoubleDot]ltnissen erfolgt in Hundertstel Halbt\[ODoubleDot]nen (Einheit ",
  
  Cell[BoxData[
      \(TraditionalForm\`Cent\)]],
  ")."
}], "Text"],

Cell[TextData[{
  "Zum Vergleich mit der in Europa verbreiteten ",
  Cell[BoxData[
      \(TraditionalForm\`12\)]],
  "-geteilten Oktave sei angegeben:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(intervallzuordnung[12] = 
      \({#, Rationalize[#, 1\/60], 
            1200 \( Log[#/Rationalize[#, 1\/60]]\/Log[2]\) "\<Cent\>" // N}&
          \)/@N[2\^\({Range[0, 6], Range[12, 6, \(-1\)]}\/12\)]; \n
    MatrixForm/@\(Transpose/@intervallzuordnung[12]\)\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          RowBox[{"(", GridBox[{
                {"1.`", "1", \(0.`\ "Cent"\)},
               
                 {"1.0594630943592953`", \(18\/17\), 
                  \(1.04540776963254966`\ "Cent"\)},
               
                 {"1.12246204830937301`", \(9\/8\), 
                  \(\(-3.91000173077486579`\)\ "Cent"\)},
               
                 {"1.18920711500272101`", \(6\/5\), 
                  \(\(-15.6412870005527215`\)\ "Cent"\)},
               
                 {"1.25992104989487296`", \(5\/4\), 
                  \(13.6862861351648357`\ "Cent"\)},
               
                 {"1.33483985417003392`", \(4\/3\), 
                  \(1.95500086538684563`\ "Cent"\)},
               
                 {"1.4142135623730951`", \(7\/5\), 
                  \(17.4878073957100044`\ "Cent"\)}
                }], ")"}],
          (MatrixForm[ #]&)], ",", 
        TagBox[
          RowBox[{"(", GridBox[{
                {"2.`", "2", \(0.`\ "Cent"\)},
               
                 {"1.88774862536338616`", \(17\/9\), 
                  \(\(-1.04540776963330173`\)\ "Cent"\)},
               
                 {"1.78179743628067903`", \(16\/9\), 
                  \(3.91000173077513544`\ "Cent"\)},
               
                 {"1.68179283050742949`", \(5\/3\), 
                  \(15.6412870005527437`\ "Cent"\)},
               
                 {"1.58740105196819918`", \(8\/5\), 
                  \(\(-13.6862861351655018`\)\ "Cent"\)},
               
                 {"1.49830707687668107`", \(3\/2\), 
                  \(\(-1.95500086538796971`\)\ "Cent"\)},
               
                 {"1.4142135623730951`", \(7\/5\), 
                  \(17.4878073957100044`\ "Cent"\)}
                }], ")"}],
          (MatrixForm[ #]&)]}], "}"}]], "Output"]
}, Open  ]],

Cell["\<\
Intervalle (und Abweichungen) werden addiert, indem die \
zugeh\[ODoubleDot]rigen Frequenzverh\[ADoubleDot]ltnisse multipliziert \
werden.\
\>", "Text"],

Cell["\<\
Die beiden rein gestimmten Dreiklang-Typen (moll und Dur) ergeben folgende \
Intervallfolgen:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(dreikl\[ADoubleDot]nge = 
      \(Times@@#&\)/@{{6\/5, 5\/4, 4\/3}, {4\/3, 5\/4, 6\/5}}\)], "Input"],

Cell[BoxData[
    \({2, 2}\)], "Output"]
}, Open  ]],

Cell["\<\
Zwei der rein gestimmten Vierklang-Typen (moll und Dur) ergeben folgende \
Intervallfolgen:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(vierkl\[ADoubleDot]nge = 
      \(Times@@#&\)/@{{8\/7, 7\/6, 6\/5, 5\/4}, {5\/4, 6\/5, 7\/6, 8\/7}}\)], 
  "Input"],

Cell[BoxData[
    \({2, 2}\)], "Output"]
}, Open  ]],

Cell["\<\
Zwei der rein gestimmten F\[UDoubleDot]nfklang-Typen (moll und Dur) ergeben \
folgende Intervallfolgen:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f\[UDoubleDot]nfkl\[ADoubleDot]nge = 
      \(Times@@#&
          \)/@{{10\/9, 9\/8, 8\/7, 7\/6, 6\/5}, {6\/5, 7\/6, 8\/7, 9\/8, 
            10\/9}}\)], "Input"],

Cell[BoxData[
    \({2, 2}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Die letztgenannten Intervallfolgen lassen sich mit der gleichschwebenden ",
  
  Cell[BoxData[
      \(TraditionalForm\`41\)]],
  "-Teilung der Oktave nicht zufriedenstellend aufbauen. Ein \
F\[UDoubleDot]nfklang (Sept-Non-Akkord) ergab auch experimentell in allen \
seinen Umkehrungen (1994, Musische Werkstatt der Uni Ulm) einen extrem \
dissonanten Eindruck. Der F\[UDoubleDot]nfklang spielt in extrem reiner \
Stimmung eine Rolle bei der Gestaltung markanter elektronischer \
Orgelregister."
}], "Text"],

Cell[TextData[{
  "Anschaulich werden reine (",
  Cell[BoxData[
      \(TraditionalForm\`n + 1\)]],
  ")-Kl\[ADoubleDot]nge erzeugt, indem jeweils das gr\[ODoubleDot]\[SZ]te \
Intervall des ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "-Klanges asymmetrisch halbiert wird."
}], "Text"],

Cell["Die Intervallfolge", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Times@@{4\/3, 9\/8, 4\/3}\)], "Input"],

Cell[BoxData[
    \(2\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "wirkt als seltsamer Dreiklang und wird wegen seiner Konsonanz auch schon \
in alten Musikst\[UDoubleDot]cken der ",
  Cell[BoxData[
      \(TraditionalForm\`12\)]],
  "-geteilten Oktave als ",
  StyleBox["Vorhalt",
    FontSlant->"Italic"],
  " vor dem eigentlichen Schlu\[SZ]akkord verwendet. Dieser Klang stellt ein \
indifferentes Zwischenst\[UDoubleDot]ck zwischen ",
  StyleBox["Dur",
    FontSlant->"Italic"],
  " und ",
  StyleBox["moll",
    FontSlant->"Italic"],
  " dar und wird daher nicht als Schlu\[SZ]akkord eingesetzt, sondern zur \
Modulation."
}], "Text"],

Cell[TextData[{
  "Bedeutsam f\[UDoubleDot]r die Musik ist, da\[SZ] sich nach Friedrich Smend \
(z.B. ",
  ButtonBox["[Sme1950]",
    ButtonData:>"[Sme1950]",
    ButtonStyle->"Hyperlink"],
  ", Seite 25-29) in den Bachschen Kompositionen auff\[ADoubleDot]llig viele \
Sequenzen mit ",
  Cell[BoxData[
      \(TraditionalForm\`14\)]],
  " oder ",
  Cell[BoxData[
      \(TraditionalForm\`41\)]],
  " Noten befinden. Ein Zusammenhang zu den Namensbeschreibungen BACH und \
J.S.BACH existiert. Die Spiegelung ist bei Bach ein wesentliches Merkmal der \
barocken Komposition."
}], "Text"],

Cell[TextData[{
  "Die technischen M\[ODoubleDot]glichkeiten, die Bachschen Kompositionen im \
Sinne einer gleichschwebenden  ",
  Cell[BoxData[
      \(TraditionalForm\`41\)]],
  "-geteilten Oktave in Siebtelt\[ODoubleDot]nen zu stimmen und aufzuf\
\[UDoubleDot]hren, sind mittlerweile \[UDoubleDot]ber die Elektronik \
vorhanden. Vor vorschnellen Trugschl\[UDoubleDot]ssen sollte auch diese \
Anregung sorgf\[ADoubleDot]ltig gepr\[UDoubleDot]ft werden. Die Gr\
\[ODoubleDot]\[SZ]e der Bachschen Musik zeigt sich vor allem dadurch, da\[SZ] \
er die M\[ODoubleDot]glichkeit einer weiteren Verfeinerung der Intonation \
beachtete: Seine eigene ",
  StyleBox["wohltemperierte",
    FontSlant->"Italic"],
  " Stimmung weicht von der gleichschwebend ",
  Cell[BoxData[
      \(TraditionalForm\`12\)]],
  "-geteilten Oktave etwas ab (",
  ButtonBox["[Bill1989]",
    ButtonData:>"[Bill1989]",
    ButtonStyle->"Hyperlink"],
  ", Seite 30-31)."
}], "Text"],

Cell[TextData[{
  "Durch die nun vorliegende Studie um die ",
  Cell[BoxData[
      \(TraditionalForm\`ArcTan[\ ]\)]],
  "-Funktion l\[ADoubleDot]\[SZ]t sich ein Teil der ",
  StyleBox["unverstandenen Restfragen aus dem Studium",
    FontSlant->"Italic"],
  " doch noch elegant beantworten."
}], "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  CounterBox["Title"],
  ".",
  CounterBox["Section"],
  ". Protokoll"
}], "Section"],

Cell[TextData[{
  "Die Version von ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " lautet:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({$Version, $ReleaseNumber, $LicenseID}\)], "Input"],

Cell[BoxData[
    \({"Microsoft Windows 3.0 (October 6, 1996)", 0, "L4526-3546"}\)], 
  "Output"]
}, Open  ]],

Cell["Die Berechnungszeit betrug (in Sekunden):", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TimeUsed[]\)], "Input"],

Cell[BoxData[
    \(12.8400000000000002`\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Literatur", "Subtitle"],

Cell[TextData[{
  "[Bill1989]\nBilleter B. ",
  StyleBox[
  "Anweisung zum Stimmen von Tasteninstrumenten in verschiedenen \
Temperaturen",
    FontSlant->"Italic"],
  ", Merseburger Kassel, 3. verbesserte Auflage, (1989)"
}], "Text",
  CellTags->"[Bill1989]"],

Cell[TextData[{
  "[GKHKR1974]\nGellert W., K\[UDoubleDot]stner H., Hellwich M., K\
\[ADoubleDot]stner H., Reichardt H. ",
  StyleBox["Kleine Enzyklop\[ADoubleDot]die Mathematik",
    FontSlant->"Italic"],
  ", VEB Bibliographisches Institut Leipzig, 9. gek\[UDoubleDot]rzte Auflage, \
(1974)"
}], "Text",
  CellTags->"[GKHKR1974]"],

Cell[TextData[{
  "[Haw1995]\nHawlitschek K. ",
  StyleBox[
  "Johann Faulhaber 1580 - 1635 Eine Bl\[UDoubleDot]tezeit der mathematischen \
Wissenschaften in Ulm",
    FontSlant->"Italic"],
  ", Ver\[ODoubleDot]ffentlichungen der Stadtbibliothek Ulm, Band ",
  StyleBox["18",
    FontWeight->"Bold"],
  ", (1995)"
}], "Text",
  CellTags->"[Haw1995]"],

Cell[TextData[{
  "[Oli1995]\nOlivastro D. ",
  StyleBox["Das chinesische Dreieck",
    FontSlant->"Italic"],
  ", Droemersche Verlagsanstalt Th. Knaur Nachf. M\[UDoubleDot]nchen, \
deutsche Ausgabe, (1995)"
}], "Text",
  CellTags->"[Oli1995]"],

Cell[TextData[{
  "[Sme1950]\nSmend F. ",
  StyleBox["Johann Sebastian Bach bei seinem Namen gerufen",
    FontSlant->"Italic"],
  ", B\[ADoubleDot]renreiter Kassel und Basel, (1950)"
}], "Text",
  CellTags->"[Sme1950]"],

Cell[TextData[{
  "[SRGT1993]\nS\[UDoubleDot]dland N., Rydyger K., Gr\[ADoubleDot]ber T., Tr\
\[UDoubleDot]stedt W.-D.  ",
  StyleBox["Wieviele T\[ODoubleDot]ne hat die Tonleiter?",
    FontSlant->"Italic"],
  ", Zeitschrift der musischen Werkstatt der Uni Ulm, (1993)"
}], "Text",
  CellTags->"[SRGT1993]"],

Cell[TextData[{
  "[Wol1997]\nWolfram S., ",
  StyleBox["Das Mathematica Buch",
    FontSlant->"Italic"],
  ", 3. Auflage Version 3, Addison-Wesley Bonn etc. 1997, auch Online-Help \
bei ",
  StyleBox["Mathematica 3.0",
    FontSlant->"Italic"]
}], "Text",
  CellTags->"[Wol1997]"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"Microsoft Windows 3.0",
ScreenRectangle->{{0, 800}, {0, 544}},
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
CellGrouping->Automatic,
WindowSize->{784, 537},
WindowMargins->{{-4, Automatic}, {-4, Automatic}},
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Inherited, Inherited, Cell[ 
        TextData[ {
          ValueBox[ "FileName"], 
          "   \[Copyright]  Norbert S\[UDoubleDot]dland"}], "Header"]}, {
    Cell[ 
        TextData[ {
          ValueBox[ "FileName"], 
          "   \[Copyright]  Norbert S\[UDoubleDot]dland"}], "Header"], 
      Inherited, Inherited}},
PrintingOptions->{"PrintingMargins"->{{72, 72}, {108, 72}},
"PaperSize"->{597.563, 842.375},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FacingPages"->True,
"Magnification"->1},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"XAutomaticEncoding",
Magnification->1.5,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    StyleMenuListing->None]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Times",
    FontSize->36,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 0.996109],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44,
    FontColor->RGBColor[0, 0, 0.996109]],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20,
    FontColor->RGBColor[0, 0, 0.996109]],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Times",
    FontSize->24,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->RGBColor[0.996109, 0, 0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36,
    FontColor->RGBColor[0.996109, 0, 0]],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14,
    FontColor->RGBColor[0.996109, 0, 0]],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0.8, 0.300008],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24,
    FontColor->RGBColor[0, 0.8, 0.300008]],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12,
    FontColor->RGBColor[0, 0.8, 0.300008]],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    CounterIncrements->"Section",
    CounterAssignments->{{"Equation", 0}, {"Figure", 0}, {"Table", 0}, {
        "Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->16,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0.500008, 0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24,
    FontColor->RGBColor[0, 0.500008, 0]],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12,
    FontColor->RGBColor[0, 0.500008, 0]],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0, 0, 0.500008],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22,
    FontColor->RGBColor[0, 0, 0.500008]],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12,
    FontColor->RGBColor[0, 0, 0.500008]],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->RGBColor[0.500008, 0, 0.500008],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18,
    FontColor->RGBColor[0.500008, 0, 0.500008]],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10,
    FontColor->RGBColor[0.500008, 0, 0.500008]],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11,
    FontColor->GrayLevel[0]]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    TextJustification->1,
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    TextJustification->1,
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    TextJustification->1,
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->1,
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    TextJustification->1,
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Times",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    TextJustification->1,
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    TextJustification->1,
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->1,
    FontSize->7]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    FontSize->16,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}},
    FontSize->11,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->OutputForm,
    CounterIncrements->"Output",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0},
    FontSize->16,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}},
    FontSize->11,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->OutputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->GrayLevel[0],
    Background->RGBColor[1, 1, 0]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16,
    FontColor->GrayLevel[0],
    Background->RGBColor[1, 1, 0]],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11,
    FontColor->GrayLevel[0],
    Background->RGBColor[1, 1, 0]],
  
  Cell[StyleData["Message", "Printout"],
    CellFrame->True,
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0],
    Background->GrayLevel[0.8]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->OutputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontColor->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16,
    FontColor->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11,
    FontColor->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}},
    FontSize->16],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}},
    FontSize->11],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Times",
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, etc.  They \
automatically give the cell a FrameLabel containing a reference to a \
particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{Inherited, 5}, {Inherited, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "Title"], ".", 
              CounterBox[ "NumberedEquation"], ")"}], FormatType -> TextForm, 
            FontWeight -> "Plain"]}, {None, None}},
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Center,
    FormatType->InputForm,
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedEquation", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation1"],
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")  "}], FormatType -> 
            TextForm, FontWeight -> "Plain"]}, {None, None}},
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Center,
    FormatType->InputForm,
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["NumberedEquation1", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedEquation1", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedEquation1", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Abbildung ", 
              CounterBox[ "Title"], ".", 
              CounterBox[ "NumberedFigure"]}]], None}},
    CounterIncrements->"NumberedFigure",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedFigure", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedFigure", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure1"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Abbildung ", 
              CounterBox[ "NumberedFigure"]}]], None}},
    CounterIncrements->"NumberedFigure",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedFigure1", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedFigure1", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedFigure1", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{44, Inherited}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Tabelle ", 
              CounterBox[ "Title"], ".", 
              CounterBox[ "NumberedTable"]}]], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedTable", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedTable", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable1"],
    CellMargins->{{44, Inherited}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {Cell[ 
            TextData[ {"Tabelle ", 
              CounterBox[ "NumberedTable"]}]], None}},
    TextAlignment->Center,
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedTable1", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["NumberedTable1", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["NumberedTable1", "Printout"],
    FontSize->10]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    FormatType->InputForm,
    ScriptLevel->1,
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0],
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{0, 0}, {6, 6}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    ZeroWidthTimes->True,
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["ChemicalFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{0, 0}, {6, 6}}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    ShowCellBracket->False,
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    TextAlignment->Center,
    FormatType->InputForm,
    ScriptLevel->0,
    StyleMenuListing->None,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0],
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    ShowCellBracket->False,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->15],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->10.5],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{0, 0}, {6, 6}},
    FontSize->9.5]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Equation"],
    DefaultFormatType->DefaultOutputFormatType,
    TextAlignment->Center,
    FormatType->InputForm,
    CounterIncrements->"Equation",
    FormatTypeAutoConvert->False,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Equation", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Equation", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["Equation", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10,
    FontWeight->"Bold",
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard ButtonFunctions, for use \
in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder objects in \
palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->Primary,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles of most \
cells.  If a cell's FormatType matches the name of one of the styles defined \
below, then that style is applied between the cell's style and its own \
options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    TextAlignment->Left,
    LineSpacing->{1.1, 0},
    StyleMenuListing->None,
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1.1, 0},
    StyleMenuListing->None,
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    StyleMenuListing->None,
    FontFamily->"Times New Roman"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None,
    FontFamily->"Times"],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an inline cell \
within another.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None,
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["InlineCell", "Presentation"],
    FontSize->16,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["InlineCell", "Condensed"],
    FontSize->11,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["InlineCell", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    FontFamily->"Times New Roman",
    Background->RGBColor[0, 0.8, 0.2]],
  
  Cell[StyleData["InlineCellEditing", "Presentation"],
    FontSize->16,
    Background->RGBColor[0, 0.8, 0.2]],
  
  Cell[StyleData["InlineCellEditing", "Condensed"],
    FontSize->11,
    Background->RGBColor[0, 0.8, 0.2]],
  
  Cell[StyleData["InlineCellEditing", "Printout"],
    FontSize->10,
    Background->GrayLevel[0.8]]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Centered Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredTitle"],
    CellMargins->{{12, 12}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Times",
    FontSize->36,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredTitle", "Presentation"],
    CellMargins->{{24, 24}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["CenteredTitle", "Condensed"],
    CellMargins->{{8, 8}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["CenteredTitle", "Printout"],
    CellMargins->{{2, 2}, {15, 30}},
    FontSize->24]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredSubtitle"],
    CellMargins->{{12, 12}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Times",
    FontSize->24,
    FontWeight->"Plain",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredSubtitle", "Presentation"],
    CellMargins->{{24, 24}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["CenteredSubtitle", "Condensed"],
    CellMargins->{{8, 8}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["CenteredSubtitle", "Printout"],
    CellMargins->{{2, 2}, {10, 15}},
    FontSize->18]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredSubsubtitle"],
    CellMargins->{{12, 12}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredSubsubtitle", "Presentation"],
    CellMargins->{{24, 24}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["CenteredSubsubtitle", "Condensed"],
    CellMargins->{{8, 8}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["CenteredSubsubtitle", "Printout"],
    CellMargins->{{2, 2}, {8, 10}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredSection"],
    CellMargins->{{12, 12}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    TextAlignment->Center,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->16,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredSection", "Presentation"],
    CellMargins->{{24, 24}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["CenteredSection", "Condensed"],
    CellMargins->{{8, 8}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["CenteredSection", "Printout"],
    CellMargins->{{2, 2}, {7, 22}},
    FontSize->14]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredSubsection"],
    CellMargins->{{12, 12}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    TextAlignment->Center,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredSubsection", "Presentation"],
    CellMargins->{{24, 24}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["CenteredSubsection", "Condensed"],
    CellMargins->{{8, 8}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["CenteredSubsection", "Printout"],
    CellMargins->{{2, 2}, {7, 22}},
    FontSize->12]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CenteredSubsubsection"],
    CellMargins->{{12, 12}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    TextAlignment->Center,
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Bold",
    FontSlant->"Plain",
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "StrikeThrough"->False}],
  
  Cell[StyleData["CenteredSubsubsection", "Presentation"],
    CellMargins->{{24, 24}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["CenteredSubsubsection", "Condensed"],
    CellMargins->{{8, 8}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["CenteredSubsubsection", "Printout"],
    CellMargins->{{2, 2}, {7, 14}},
    FontSize->11]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation package. These \
styles serve to make visible otherwise invisible tagboxes.\
\>", "Text",
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    CellTags->"NotationPackage"]
  }, Open  ]]
  }, Open  ]]
  }]
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Quadratwurzeln"->{
    Cell[59461, 2093, 734, 14, 330, "NumberedEquation",
      CellTags->"Quadratwurzeln"]},
  "[Bill1989]"->{
    Cell[79635, 2734, 260, 8, 93, "Text",
      CellTags->"[Bill1989]"]},
  "[GKHKR1974]"->{
    Cell[79898, 2744, 332, 8, 93, "Text",
      CellTags->"[GKHKR1974]"]},
  "[Haw1995]"->{
    Cell[80233, 2754, 350, 11, 93, "Text",
      CellTags->"[Haw1995]"]},
  "[Oli1995]"->{
    Cell[80586, 2767, 244, 7, 93, "Text",
      CellTags->"[Oli1995]"]},
  "[Sme1950]"->{
    Cell[80833, 2776, 220, 6, 69, "Text",
      CellTags->"[Sme1950]"]},
  "[SRGT1993]"->{
    Cell[81056, 2784, 307, 7, 93, "Text",
      CellTags->"[SRGT1993]"]},
  "[Wol1997]"->{
    Cell[81366, 2793, 281, 9, 93, "Text",
      CellTags->"[Wol1997]"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Quadratwurzeln", 122892, 4273},
  {"[Bill1989]", 123002, 4276},
  {"[GKHKR1974]", 123095, 4279},
  {"[Haw1995]", 123187, 4282},
  {"[Oli1995]", 123278, 4285},
  {"[Sme1950]", 123368, 4288},
  {"[SRGT1993]", 123459, 4291},
  {"[Wol1997]", 123550, 4294}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 262, 3, 154, "Title",
  CounterAssignments->{{"Title", 20}, {"SubTitle", 0}, {"SubSubTitle", 0}, {
      "Section", 0}, {"SubSection", 0}, {"SubSubSection", 0}, {
      "NumberedEquation", 0}, {"NumberedFigure", 0}, {"NumberedTable", 0}}],
Cell[1996, 56, 239, 5, 120, "Subsubtitle"],

Cell[CellGroupData[{
Cell[2260, 65, 97, 5, 76, "Section"],
Cell[2360, 72, 160, 5, 45, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2557, 82, 99, 5, 76, "Section"],

Cell[CellGroupData[{
Cell[2681, 91, 142, 7, 68, "Subsection"],

Cell[CellGroupData[{
Cell[2848, 102, 233, 11, 61, "Subsubsection"],
Cell[3084, 115, 441, 10, 117, "Text"],

Cell[CellGroupData[{
Cell[3550, 129, 1156, 20, 591, "Input"],
Cell[4709, 151, 47, 1, 41, "Output"]
}, Open  ]],
Cell[4771, 155, 283, 7, 69, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5091, 167, 242, 11, 61, "Subsubsection"],
Cell[5336, 180, 98, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[5459, 186, 417, 8, 366, "Input"],
Cell[5879, 196, 49, 1, 41, "Output"]
}, Open  ]],
Cell[5943, 200, 88, 1, 45, "Text"],

Cell[CellGroupData[{
Cell[6056, 205, 1038, 18, 795, "Input"],
Cell[7097, 225, 54, 1, 41, "Output"]
}, Open  ]],
Cell[7166, 229, 195, 4, 69, "Text"],

Cell[CellGroupData[{
Cell[7386, 237, 111, 2, 41, "Input"],
Cell[7500, 241, 82, 1, 65, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7619, 247, 127, 2, 41, "Input"],
Cell[7749, 251, 79, 1, 54, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7865, 257, 78, 1, 43, "Input"],
Cell[7946, 260, 61, 1, 63, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8068, 268, 154, 7, 68, "Subsection"],

Cell[CellGroupData[{
Cell[8247, 279, 181, 9, 61, "Subsubsection"],
Cell[8431, 290, 683, 22, 93, "Text"],

Cell[CellGroupData[{
Cell[9139, 316, 229, 3, 95, "Input"],
Cell[9371, 321, 50, 1, 41, "Output"]
}, Open  ]],
Cell[9436, 325, 347, 7, 93, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9820, 337, 226, 9, 61, "Subsubsection"],
Cell[10049, 348, 321, 9, 69, "Text"],

Cell[CellGroupData[{
Cell[10395, 361, 130, 2, 97, "Input"],
Cell[10528, 365, 155, 3, 64, "Output"],
Cell[10686, 370, 38, 1, 41, "Output"]
}, Open  ]],
Cell[10739, 374, 234, 8, 45, "Text"],

Cell[CellGroupData[{
Cell[10998, 386, 88, 1, 41, "Input"],
Cell[11089, 389, 154, 3, 84, "Message"],
Cell[11246, 394, 154, 3, 84, "Message"],
Cell[11403, 399, 194, 3, 74, "Output"]
}, Open  ]],
Cell[11612, 405, 477, 15, 93, "Text"],

Cell[CellGroupData[{
Cell[12114, 424, 54, 1, 41, "Input"],
Cell[12171, 427, 87, 1, 41, "Output"]
}, Open  ]],
Cell[12273, 431, 74, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[12372, 435, 57, 1, 41, "Input"],
Cell[12432, 438, 119, 2, 74, "Output"]
}, Open  ]],
Cell[12566, 443, 482, 14, 69, "Text"],
Cell[13051, 459, 203, 4, 69, "Text"],

Cell[CellGroupData[{
Cell[13279, 467, 130, 3, 44, "Input"],
Cell[13412, 472, 51, 1, 63, "Output"]
}, Open  ]],
Cell[13478, 476, 33, 0, 45, "Text"],
Cell[13514, 478, 100, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[13639, 487, 42, 1, 41, "Input"],
Cell[13684, 490, 119, 2, 74, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13840, 497, 147, 3, 41, "Input"],
Cell[13990, 502, 111, 2, 63, "Output"]
}, Open  ]],
Cell[14116, 507, 124, 3, 69, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14277, 515, 207, 9, 61, "Subsubsection"],
Cell[14487, 526, 124, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[14636, 533, 40, 1, 41, "Input"],
Cell[14679, 536, 51, 1, 63, "Output"]
}, Open  ]],
Cell[14745, 540, 114, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[14884, 547, 174, 4, 41, "Input"],
Cell[15061, 553, 73, 1, 63, "Output"]
}, Open  ]],
Cell[15149, 557, 71, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[15245, 561, 159, 3, 41, "Input"],
Cell[15407, 566, 73, 1, 63, "Output"]
}, Open  ]],
Cell[15495, 570, 58, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[15578, 574, 209, 5, 71, "Input"],
Cell[15790, 581, 73, 1, 63, "Output"]
}, Open  ]],
Cell[15878, 585, 108, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[16011, 592, 54, 1, 41, "Input"],
Cell[16068, 595, 38, 1, 41, "Output"]
}, Open  ]],
Cell[16121, 599, 226, 5, 69, "Text"],

Cell[CellGroupData[{
Cell[16372, 608, 172, 4, 41, "Input"],
Cell[16547, 614, 73, 1, 63, "Output"]
}, Open  ]],
Cell[16635, 618, 65, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[16725, 622, 97, 2, 41, "Input"],
Cell[16825, 626, 51, 1, 63, "Output"]
}, Open  ]],
Cell[16891, 630, 197, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[17113, 639, 103, 2, 61, "Input"],
Cell[17219, 643, 119, 2, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17375, 650, 113, 2, 61, "Input"],
Cell[17491, 654, 119, 2, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17647, 661, 110, 2, 61, "Input"],
Cell[17760, 665, 119, 2, 59, "Output"]
}, Open  ]],
Cell[17894, 670, 59, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[17978, 674, 82, 1, 41, "Input"],
Cell[18063, 677, 45, 1, 41, "Output"]
}, Open  ]],
Cell[18123, 681, 160, 5, 45, "Text"],
Cell[18286, 688, 339, 7, 93, "Text"],

Cell[CellGroupData[{
Cell[18650, 699, 155, 3, 62, "Input"],
Cell[18808, 704, 128, 2, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18973, 711, 161, 3, 62, "Input"],
Cell[19137, 716, 120, 2, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19294, 723, 158, 3, 62, "Input"],
Cell[19455, 728, 113, 2, 59, "Output"]
}, Open  ]],
Cell[19583, 733, 74, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[19682, 737, 156, 3, 67, "Input"],
Cell[19841, 742, 84, 1, 59, "Output"]
}, Open  ]],
Cell[19940, 746, 115, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[20080, 753, 85, 1, 41, "Input"],
Cell[20168, 756, 37, 1, 41, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[20254, 763, 249, 12, 62, "Subsubsection"],
Cell[20506, 777, 594, 14, 117, "Text"],
Cell[21103, 793, 309, 5, 93, "Text"],
Cell[21415, 800, 164, 5, 45, "Text"],
Cell[21582, 807, 473, 8, 141, "Text"],
Cell[22058, 817, 369, 6, 117, "Text"],
Cell[22430, 825, 311, 7, 69, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22778, 837, 207, 9, 61, "Subsubsection"],
Cell[22988, 848, 43, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[23056, 852, 99, 2, 44, "Input"],
Cell[23158, 856, 55, 1, 68, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23250, 862, 80, 1, 44, "Input"],
Cell[23333, 865, 55, 1, 63, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23425, 871, 80, 1, 44, "Input"],
Cell[23508, 874, 92, 1, 68, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23637, 880, 80, 1, 44, "Input"],
Cell[23720, 883, 49, 1, 63, "Output"]
}, Open  ]],
Cell[23784, 887, 159, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[23968, 896, 130, 2, 41, "Input"],
Cell[24101, 900, 51, 1, 63, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24189, 906, 137, 2, 41, "Input"],
Cell[24329, 910, 51, 1, 63, "Output"]
}, Open  ]],
Cell[24395, 914, 156, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[24576, 923, 92, 1, 41, "Input"],
Cell[24671, 926, 91, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24799, 932, 92, 1, 41, "Input"],
Cell[24894, 935, 100, 2, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25031, 942, 92, 1, 41, "Input"],
Cell[25126, 945, 89, 1, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25252, 951, 52, 1, 41, "Input"],
Cell[25307, 954, 84, 1, 59, "Output"]
}, Open  ]],
Cell[25406, 958, 123, 3, 45, "Text"],
Cell[25532, 963, 239, 6, 69, "Text"],

Cell[CellGroupData[{
Cell[25796, 973, 338, 8, 94, "Input"],
Cell[26137, 983, 175, 3, 74, "Output"]
}, Open  ]],
Cell[26327, 989, 49, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[26401, 993, 91, 1, 44, "Input"],
Cell[26495, 996, 51, 1, 63, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26583, 1002, 67, 1, 41, "Input"],
Cell[26653, 1005, 37, 1, 41, "Output"]
}, Open  ]],
Cell[26705, 1009, 344, 9, 71, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27086, 1023, 215, 9, 61, "Subsubsection"],
Cell[27304, 1034, 367, 8, 93, "Text"],
Cell[27674, 1044, 306, 5, 93, "Text"],
Cell[27983, 1051, 120, 3, 45, "Text"],
Cell[28106, 1056, 166, 3, 48, "NumberedEquation"],
Cell[28275, 1061, 596, 14, 117, "Text"],
Cell[28874, 1077, 175, 5, 45, "Text"],
Cell[29052, 1084, 353, 6, 44, "NumberedEquation"],
Cell[29408, 1092, 311, 11, 45, "Text"],
Cell[29722, 1105, 590, 17, 117, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30349, 1127, 201, 9, 61, "Subsubsection"],
Cell[30553, 1138, 283, 8, 69, "Text"],

Cell[CellGroupData[{
Cell[30861, 1150, 143, 3, 41, "Input"],
Cell[31007, 1155, 119, 3, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31163, 1163, 143, 3, 41, "Input"],
Cell[31309, 1168, 134, 4, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31480, 1177, 143, 3, 41, "Input"],
Cell[31626, 1182, 127, 3, 59, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31790, 1190, 115, 3, 41, "Input"],
Cell[31908, 1195, 101, 2, 63, "Output"]
}, Open  ]],
Cell[32024, 1200, 214, 4, 69, "Text"],
Cell[32241, 1206, 476, 10, 93, "Text"],
Cell[32720, 1218, 184, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[32929, 1227, 43, 1, 41, "Input"],
Cell[32975, 1230, 175, 3, 74, "Output"]
}, Open  ]],
Cell[33165, 1236, 153, 3, 69, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[33367, 1245, 163, 7, 68, "Subsection"],

Cell[CellGroupData[{
Cell[33555, 1256, 231, 10, 61, "Subsubsection"],
Cell[33789, 1268, 314, 7, 93, "Text"],

Cell[CellGroupData[{
Cell[34128, 1279, 99, 2, 41, "Input"],
Cell[34230, 1283, 868, 15, 278, "Output"]
}, Open  ]],
Cell[35113, 1301, 122, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[35260, 1308, 121, 3, 41, "Input"],
Cell[35384, 1313, 380, 7, 178, "Output"]
}, Open  ]],
Cell[35779, 1323, 326, 9, 69, "Text"],

Cell[CellGroupData[{
Cell[36130, 1336, 86, 1, 41, "Input"],
Cell[36219, 1339, 205, 4, 66, "Output"]
}, Open  ]],
Cell[36439, 1346, 316, 7, 69, "Text"],
Cell[36758, 1355, 584, 13, 141, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37379, 1373, 250, 13, 61, "Subsubsection"],
Cell[37632, 1388, 929, 24, 165, "Text"],
Cell[38564, 1414, 403, 10, 93, "Text"],

Cell[CellGroupData[{
Cell[38992, 1428, 88, 1, 66, "Input"],
Cell[39083, 1431, 231, 4, 66, "Output"]
}, Open  ]],
Cell[39329, 1438, 345, 7, 93, "Text"],
Cell[39677, 1447, 383, 11, 87, "Text"],
Cell[40063, 1460, 537, 11, 125, "Text"],

Cell[CellGroupData[{
Cell[40625, 1475, 302, 5, 171, "Input"],
Cell[40930, 1482, 2887, 97, 131, "Output"]
}, Open  ]],
Cell[43832, 1582, 278, 9, 69, "Text"],
Cell[44113, 1593, 290, 5, 93, "Text"],
Cell[44406, 1600, 246, 6, 69, "Text"],

Cell[CellGroupData[{
Cell[44677, 1610, 109, 2, 43, "Input"],
Cell[44789, 1614, 251, 4, 69, "Output"]
}, Open  ]],
Cell[45055, 1621, 662, 14, 149, "Text"],
Cell[45720, 1637, 42, 0, 45, "Text"],
Cell[45765, 1639, 368, 8, 141, "Text"],
Cell[46136, 1649, 241, 4, 93, "Text"],
Cell[46380, 1655, 1166, 31, 213, "Text"],
Cell[47549, 1688, 214, 4, 69, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47800, 1697, 211, 10, 61, "Subsubsection"],
Cell[48014, 1709, 354, 8, 93, "Text"],
Cell[48371, 1719, 361, 6, 117, "Text"],
Cell[48735, 1727, 74, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[48834, 1731, 181, 4, 74, "Input"],
Cell[49018, 1737, 716, 25, 95, "Output"]
}, Open  ]],
Cell[49749, 1765, 97, 2, 45, "Text"],

Cell[CellGroupData[{
Cell[49871, 1771, 121, 2, 72, "Input"],
Cell[49995, 1775, 813, 28, 95, "Output"]
}, Open  ]],
Cell[50823, 1806, 181, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[51029, 1815, 163, 3, 72, "Input"],
Cell[51195, 1820, 633, 22, 91, "Output"]
}, Open  ]],
Cell[51843, 1845, 172, 4, 69, "Text"],

Cell[CellGroupData[{
Cell[52040, 1853, 181, 3, 66, "Input"],
Cell[52224, 1858, 3538, 111, 189, "Output"]
}, Open  ]],
Cell[55777, 1972, 135, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[55937, 1979, 232, 6, 122, "Input"],
Cell[56172, 1987, 415, 11, 153, "Output"]
}, Open  ]],
Cell[56602, 2001, 221, 6, 69, "Text"],

Cell[CellGroupData[{
Cell[56848, 2011, 213, 4, 66, "Input"],
Cell[57064, 2017, 1873, 59, 111, "Output"]
}, Open  ]],
Cell[58952, 2079, 303, 5, 93, "Text"],
Cell[59258, 2086, 200, 5, 45, "Text"],
Cell[59461, 2093, 734, 14, 330, "NumberedEquation",
  CellTags->"Quadratwurzeln"],
Cell[60198, 2109, 308, 4, 93, "Text"],
Cell[60509, 2115, 252, 8, 69, "Text"],
Cell[60764, 2125, 470, 9, 185, "NumberedEquation"],
Cell[61237, 2136, 117, 3, 45, "Text"],
Cell[61357, 2141, 443, 8, 117, "Text"],
Cell[61803, 2151, 518, 15, 93, "Text"],
Cell[62324, 2168, 277, 5, 93, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[62638, 2178, 199, 9, 61, "Subsubsection"],
Cell[62840, 2189, 181, 6, 45, "Text"],

Cell[CellGroupData[{
Cell[63046, 2199, 43, 1, 41, "Input"],
Cell[63092, 2202, 71, 1, 35, "Print"]
}, Open  ]],
Cell[63178, 2206, 293, 7, 93, "Text"],

Cell[CellGroupData[{
Cell[63496, 2217, 172, 3, 216, "Input"],
Cell[63671, 2222, 43, 1, 41, "Output"]
}, Open  ]],
Cell[63729, 2226, 111, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[63865, 2233, 90, 1, 41, "Input"],
Cell[63958, 2236, 276, 7, 108, "Output"]
}, Open  ]],
Cell[64249, 2246, 264, 7, 69, "Text"],

Cell[CellGroupData[{
Cell[64538, 2257, 42, 1, 41, "Input"],
Cell[64583, 2260, 36, 1, 41, "Output"]
}, Open  ]],
Cell[64634, 2264, 660, 15, 141, "Text"],
Cell[65297, 2281, 234, 6, 69, "Text"],

Cell[CellGroupData[{
Cell[65556, 2291, 234, 4, 78, "Input"],
Cell[65793, 2297, 2627, 66, 83, "Output"]
}, Open  ]],
Cell[68435, 2366, 262, 7, 69, "Text"],

Cell[CellGroupData[{
Cell[68722, 2377, 260, 5, 174, "Input"],
Cell[68985, 2384, 2630, 66, 371, "Output"]
}, Open  ]],
Cell[71630, 2453, 240, 7, 69, "Text"],
Cell[71873, 2462, 164, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[72062, 2471, 293, 5, 190, "Input"],
Cell[72358, 2478, 1866, 48, 260, "Output"]
}, Open  ]],
Cell[74239, 2529, 162, 4, 69, "Text"],
Cell[74404, 2535, 117, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[74546, 2542, 120, 2, 66, "Input"],
Cell[74669, 2546, 40, 1, 41, "Output"]
}, Open  ]],
Cell[74724, 2550, 115, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[74864, 2557, 135, 3, 66, "Input"],
Cell[75002, 2562, 40, 1, 41, "Output"]
}, Open  ]],
Cell[75057, 2566, 127, 3, 45, "Text"],

Cell[CellGroupData[{
Cell[75209, 2573, 182, 4, 66, "Input"],
Cell[75394, 2579, 40, 1, 41, "Output"]
}, Open  ]],
Cell[75449, 2583, 526, 11, 141, "Text"],
Cell[75978, 2596, 293, 9, 69, "Text"],
Cell[76274, 2607, 34, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[76333, 2611, 58, 1, 66, "Input"],
Cell[76394, 2614, 35, 1, 41, "Output"]
}, Open  ]],
Cell[76444, 2618, 591, 17, 117, "Text"],
Cell[77038, 2637, 585, 16, 117, "Text"],
Cell[77626, 2655, 950, 22, 165, "Text"],
Cell[78579, 2679, 303, 8, 69, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[78943, 2694, 101, 5, 76, "Section"],
Cell[79047, 2701, 114, 5, 45, "Text"],

Cell[CellGroupData[{
Cell[79186, 2710, 71, 1, 41, "Input"],
Cell[79260, 2713, 97, 2, 41, "Output"]
}, Open  ]],
Cell[79372, 2718, 57, 0, 45, "Text"],

Cell[CellGroupData[{
Cell[79454, 2722, 43, 1, 41, "Input"],
Cell[79500, 2725, 54, 1, 41, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[79603, 2732, 29, 0, 80, "Subtitle"],
Cell[79635, 2734, 260, 8, 93, "Text",
  CellTags->"[Bill1989]"],
Cell[79898, 2744, 332, 8, 93, "Text",
  CellTags->"[GKHKR1974]"],
Cell[80233, 2754, 350, 11, 93, "Text",
  CellTags->"[Haw1995]"],
Cell[80586, 2767, 244, 7, 93, "Text",
  CellTags->"[Oli1995]"],
Cell[80833, 2776, 220, 6, 69, "Text",
  CellTags->"[Sme1950]"],
Cell[81056, 2784, 307, 7, 93, "Text",
  CellTags->"[SRGT1993]"],
Cell[81366, 2793, 281, 9, 93, "Text",
  CellTags->"[Wol1997]"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

